@@ -31,7 +31,11 @@
 #include "objecttree.h"
 #include "KexiJsonTrader.h"
 #include "KexiFormWidgetsPluginMetaData.h"
+#include "KexiVersion.h"
 #include <core/kexiguimsghandler.h>
+#define KEXI_SKIP_SETUPBREEZEICONTHEME
+#define KEXI_SKIP_REGISTERRESOURCE
+#include <main/KexiRegisterResource_p.h>
 
 #include <KActionCollection>
 #include <KLocalizedString>
@@ -43,10 +47,10 @@
 namespace KFormDesigner
 {
 
-Q_GLOBAL_STATIC_WITH_ARGS(KexiJsonTrader, KexiFormWidgetsPluginTrader_instance, ("kexi/forms/widgets"))
+Q_GLOBAL_STATIC_WITH_ARGS(KexiJsonTrader, KexiFormWidgetsPluginTrader_instance, (KEXI_BASE_PATH "/forms/widgets"))
 
 //! @internal
-class WidgetLibrary::Private
+class Q_DECL_HIDDEN WidgetLibrary::Private
 {
 public:
     Private(WidgetLibrary *library, const QStringList& supportedFactoryGroups)
@@ -55,6 +59,7 @@ public:
             , m_couldNotFindAnyFormWidgetPluginsErrorDisplayed(false)
             , m_supportedFactoryGroups(supportedFactoryGroups.toSet())
             , m_lookupDone(false)
+            , m_lookupResult(false)
             , m_loadFactoriesDone(false)
     {
         q->setMessageHandler(&messageHandler);
@@ -137,7 +142,7 @@ private:
         q->clearResult();
 
         QStringList serviceTypes;
-        serviceTypes << "Kexi/FormWidgets";
+        serviceTypes << "Kexi/FormWidget";
         QList<QPluginLoader*> offers = KexiFormWidgetsPluginTrader_instance->query(serviceTypes);
         foreach(const QPluginLoader *loader, offers) {
             QScopedPointer<KexiFormWidgetsPluginMetaData> metaData(new KexiFormWidgetsPluginMetaData(*loader));
@@ -147,7 +152,8 @@ private:
                 continue;
             }
             // check version
-            if (metaData->majorVersion() != KFormDesigner::version()) {
+            const QString expectedVersion = KFormDesigner::version();
+            if (metaData->version() != expectedVersion) {
                 qWarning() << "Kexi Form Widgets plugin" << metaData->id() << "has version"
                            << metaData->majorVersion() << "but required version is" << KFormDesigner::version()
                            << "-- skipping!";
@@ -168,6 +174,15 @@ private:
                          << "is not supported -- skipping!";
                 continue;
             }
+            if (!setupPrivateIconsResourceWithMessage(
+                QLatin1String(KEXI_BASE_PATH),
+                QString::fromLatin1("icons/%1_%2.rcc")
+                    .arg(metaData->id()).arg(supportedIconTheme),
+                QtWarningMsg,
+                QString::fromLatin1(":/icons/%1").arg(metaData->id())))
+            {
+                continue;
+            }
 
             m_pluginsMetaData.insert(metaData->id(), metaData.data());
             metaData.take();
@@ -475,7 +490,6 @@ QString WidgetLibrary::displayName(const QByteArray &classname)
 
 QString WidgetLibrary::savingName(const QByteArray &classname)
 {
-    QString s;
     WidgetInfo *wi = d->widgets().value(classname);
     if (wi && !wi->savingName().isEmpty())
         return wi->savingName();
@@ -757,7 +771,7 @@ bool WidgetLibrary::propertySetShouldBeReloadedAfterPropertyChange(
 
 ObjectTreeItem* WidgetLibrary::selectableItem(ObjectTreeItem* item)
 {
-    qDebug() << item->widget()->metaObject()->className();
+    //qDebug() << item->widget()->metaObject()->className();
     WidgetInfo *wi = d->widgets().value(item->widget()->metaObject()->className());
     if (!wi)
         return item;
