@@ -34,6 +34,7 @@
 #include "kexiutils_global.h"
 #include <KexiIcon.h>
 
+#include <QDomNode>
 #include <QPainter>
 #include <QImage>
 #include <QImageReader>
@@ -61,14 +62,18 @@
 #include <QLineEdit>
 #include <QProcess>
 
+#ifndef KEXI_MOBILE
 #include <kio_version.h>
 #include <KRun>
 #include <KToolInvocation>
-#include <KIconEffect>
-#include <KColorScheme>
-#include <KLocalizedString>
-#include <KConfigGroup>
+#endif
 #include <KAboutData>
+#include <KColorScheme>
+#include <KConfigGroup>
+#include <KFileWidget>
+#include <KIconEffect>
+#include <KLocalizedString>
+#include <KRecentDirs>
 
 #if HAVE_LANGINFO_H
 #include <langinfo.h>
@@ -85,27 +90,38 @@ static QRgb qt_colorref2qrgb(COLORREF col)
 
 using namespace KexiUtils;
 
-DelayedCursorHandler::DelayedCursorHandler()
-        : startedOrActive(false)
+DelayedCursorHandler::DelayedCursorHandler(QWidget *widget)
+        : startedOrActive(false), m_widget(widget), m_handleWidget(widget)
 {
-    timer.setSingleShot(true);
-    connect(&timer, SIGNAL(timeout()), this, SLOT(show()));
+    m_timer.setSingleShot(true);
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(show()));
 }
 void DelayedCursorHandler::start(bool noDelay)
 {
     startedOrActive = true;
-    timer.start(noDelay ? 0 : 1000);
+    m_timer.start(noDelay ? 0 : 1000);
 }
 void DelayedCursorHandler::stop()
 {
     startedOrActive = false;
-    timer.stop();
-    QApplication::restoreOverrideCursor();
+    m_timer.stop();
+    if (m_handleWidget && m_widget) {
+        m_widget->unsetCursor();
+    } else {
+        QApplication::restoreOverrideCursor();
+    }
 }
+
 void DelayedCursorHandler::show()
 {
-    QApplication::restoreOverrideCursor();
-    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    const QCursor waitCursor(Qt::WaitCursor);
+    if (m_handleWidget && m_widget) {
+        m_widget->unsetCursor();
+        m_widget->setCursor(waitCursor);
+    } else {
+        QApplication::restoreOverrideCursor();
+        QApplication::setOverrideCursor(waitCursor);
+    }
 }
 
 Q_GLOBAL_STATIC(DelayedCursorHandler, _delayedCursorHandler)
@@ -125,13 +141,26 @@ void KexiUtils::removeWaitCursor()
 }
 
 WaitCursor::WaitCursor(bool noDelay)
+    : m_handler(nullptr)
 {
     setWaitCursor(noDelay);
 }
 
+WaitCursor::WaitCursor(QWidget *widget, bool noDelay)
+{
+    DelayedCursorHandler *handler = new DelayedCursorHandler(widget);
+    handler->start(noDelay);
+    m_handler = handler;
+}
+
 WaitCursor::~WaitCursor()
 {
-    removeWaitCursor();
+    if (m_handler) {
+        qobject_cast<DelayedCursorHandler*>(m_handler)->stop();
+        delete m_handler;
+    } else {
+        removeWaitCursor();
+    }
 }
 
 WaitCursorRemover::WaitCursorRemover()
@@ -258,53 +287,6 @@ QStringList KexiUtils::enumKeysForProperty(const QMetaProperty& metaProperty, in
     return result;
 }
 
-QString KexiUtils::fileDialogFilterString(const QMimeType &mime, bool kdeFormat)
-{
-    if (!mime.isValid()) {
-        return QString();
-    }
-
-    QString str;
-    if (kdeFormat) {
-        if (mime.globPatterns().isEmpty()) {
-            str = "*";
-        } else {
-            str = mime.globPatterns().join(" ");
-        }
-        str += "|";
-    }
-    str += mime.comment();
-    if (!mime.globPatterns().isEmpty() || !kdeFormat) {
-        str += " (";
-        if (mime.globPatterns().isEmpty())
-            str += "*";
-        else
-            str += mime.globPatterns().join("; ");
-        str += ")";
-    }
-    if (kdeFormat)
-        str += "\n";
-    else
-        str += ";;";
-    return str;
-}
-
-QString KexiUtils::fileDialogFilterString(const QString& mimeName, bool kdeFormat)
-{
-    QMimeDatabase db;
-    QMimeType mime = db.mimeTypeForName(mimeName);
-    return fileDialogFilterString(mime, kdeFormat);
-}
-
-QString KexiUtils::fileDialogFilterStrings(const QStringList& mimeStrings, bool kdeFormat)
-{
-    QString ret;
-    QStringList::ConstIterator endIt = mimeStrings.constEnd();
-    for (QStringList::ConstIterator it = mimeStrings.constBegin(); it != endIt; ++it)
-        ret += fileDialogFilterString(*it, kdeFormat);
-    return ret;
-}
-
 //! @internal
 static QFileDialog* getImageDialog(QWidget *parent, const QString &caption, const QUrl &directory,
                                    const QList<QByteArray> &supportedMimeTypes)
@@ -344,6 +326,43 @@ QUrl KexiUtils::getSaveImageUrl(QWidget *parent, const QString &caption, const Q
     }
 }
 
+QUrl KexiUtils::getStartUrl(const QUrl &startDirOrVariable, QString *recentDirClass)
+{
+    QUrl result;
+    if (recentDirClass) {
+        result = KFileWidget::getStartUrl(startDirOrVariable, *recentDirClass);
+        // Fix bug introduced by Kexi 3.0.x in KexiFileWidget: remove file protocol from path
+        // (the KRecentDirs::add(.., dir.url()) call was invalid because of prepended protocol)
+        const QString protocol("file:/");
+        if (result.path().startsWith(protocol) && !result.path().startsWith(protocol + '/')) {
+            result.setPath(result.path().mid(protocol.length() - 1));
+        }
+    } else {
+        qWarning() << "Missing recentDirClass";
+    }
+    return result;
+}
+
+void KexiUtils::addRecentDir(const QString &fileClass, const QString &directory)
+{
+    KRecentDirs::add(fileClass, directory);
+}
+
+bool KexiUtils::askForFileOverwriting(const QString& filePath, QWidget *parent)
+{
+    QFileInfo fi(filePath);
+    if (!fi.exists()) {
+        return true;
+    }
+    const KMessageBox::ButtonCode res = KMessageBox::warningYesNo(parent,
+                    xi18nc("@info", "<para>The file <filename>%1</filename> already exists.</para>"
+                           "<para>Do you want to overwrite it?</para>",
+                           QDir::toNativeSeparators(filePath)),
+                    QString(),
+                    KStandardGuiItem::overwrite(), KStandardGuiItem::no());
+    return res == KMessageBox::Yes;
+}
+
 QColor KexiUtils::blendedColors(const QColor& c1, const QColor& c2, int factor1, int factor2)
 {
     return QColor(
@@ -723,6 +742,7 @@ bool PaintBlocker::eventFilter(QObject* watched, QEvent* event)
 
 tristate KexiUtils::openHyperLink(const QUrl &url, QWidget *parent, const OpenHyperlinkOptions &options)
 {
+#ifndef KEXI_MOBILE
     if (url.isLocalFile()) {
         QFileInfo fileInfo(url.toLocalFile());
         if (!fileInfo.exists()) {
@@ -759,7 +779,7 @@ tristate KexiUtils::openHyperLink(const QUrl &url, QWidget *parent, const OpenHy
                     , QString()
                     , KGuiItem(xi18nc("@action:button Run script file", "Run"), koIconName("system-run"))
                     , KStandardGuiItem::no()
-                    , "AllowRunExecutable", KMessageBox::Dangerous);
+                    , "AllowRunExecutable", KMessageBox::Notify | KMessageBox::Dangerous);
 
         if (ret != KMessageBox::Yes) {
             return cancelled;
@@ -779,6 +799,7 @@ tristate KexiUtils::openHyperLink(const QUrl &url, QWidget *parent, const OpenHy
             return QDesktopServices::openUrl(url);
         default:;
     }
+#endif
     return false;
 }
 
@@ -921,8 +942,11 @@ GraphicEffects KexiUtils::graphicEffectsLevel()
 class DetectedDesktopSession
 {
 public:
-    DetectedDesktopSession() : name(detect()) {}
+    DetectedDesktopSession() : name(detect()), isKDE(name == QStringLiteral("KDE"))
+    {
+    }
     const QByteArray name;
+    const bool isKDE;
 
 private:
     static QByteArray detect() {
@@ -961,6 +985,21 @@ QByteArray KexiUtils::detectedDesktopSession()
     return s_detectedDesktopSession->name;
 }
 
+bool KexiUtils::isKDEDesktopSession()
+{
+    return s_detectedDesktopSession->isKDE;
+}
+
+bool KexiUtils::shouldUseNativeDialogs()
+{
+#if defined Q_OS_UNIX && !defined Q_OS_MACOS
+    return isKDEDesktopSession() || detectedDesktopSession().isEmpty();
+#else
+    return true;
+#endif
+}
+
+
 //! @return value of XFCE property @a property for channel @a channel
 //! Sets the value pointed by @a ok to status.
 //! @todo Should be part of desktop integration or KF
@@ -971,28 +1010,30 @@ static QByteArray xfceSettingValue(const QByteArray &channel, const QByteArray &
         *ok = false;
     }
     QByteArray result;
-    const QString command = QString::fromLatin1("xfconf-query -c \"%1\" -p \"%2\"")
-                                .arg(channel.constData())
-                                .arg(property.constData());
+    const QString program = QString::fromLatin1("xfconf-query");
+    const QString programPath = QStandardPaths::findExecutable(program);
+    const QStringList arguments{ program, "-c", channel, "-p", property };
     QProcess process;
-    process.start(command, QIODevice::ReadOnly | QIODevice::Text);
+    process.start(programPath, arguments);//, QIODevice::ReadOnly | QIODevice::Text);
+    qDebug() << "a" << int(process.exitCode());
     if (!process.waitForStarted()) {
-        qWarning() << "Count not execute command" << command << "error:" << process.error();
+        qWarning() << "Count not execute command" << programPath << arguments
+                   << "error:" << process.error();
         return QByteArray();
     }
-    if (!process.waitForFinished() || process.exitStatus() != QProcess::NormalExit) {
-        qWarning() << "Count not finish command" << command << "error:" << process.error()
+    const int exitCode = process.exitCode(); // !=0 e.g. for "no such property or channel"
+    if (exitCode != 0 || !process.waitForFinished() || process.exitStatus() != QProcess::NormalExit) {
+        qWarning() << "Count not finish command" << programPath << arguments
+                   << "error:" << process.error() << "exit code:" << exitCode
                    << "exit status:" << process.exitStatus();
         return QByteArray();
     }
     if (ok) {
         *ok = true;
     }
-    if (process.exitCode() == 0) {
-        result = process.readAll();
-        result.chop(1);
-    }
-    return result;  // !=0 e.g. for "no such property or channel"
+    result = process.readAll();
+    result.chop(1);
+    return result;
 }
 
 #else
@@ -1147,3 +1188,12 @@ bool KexiUtils::cursorAtEnd(const QLineEdit *lineEdit)
         return lineEdit->cursorPosition() >= (lineEdit->displayText().length() - 1);
     }
 }
+
+QDebug operator<<(QDebug dbg, const QDomNode &node)
+{
+  QString s;
+  QTextStream str(&s, QIODevice::WriteOnly);
+  node.save(str, 2);
+  dbg << qPrintable(s);
+  return dbg;
+}
