@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2018 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -96,6 +96,8 @@ public:
 
     void addSearchableModel(KexiSearchableModel *model);
 
+    void removeSearchableModel(KexiSearchableModel *model);
+
     KToolBar *createToolBar(const char *name, const QString& caption);
 
     void setCurrentTab(const QString& name);
@@ -252,6 +254,9 @@ public Q_SLOTS:
     void toggleMainMenu();
     void updateMainMenuGeometry();
 
+    //! Initializes global search line edit. If it is enabled, it's created, if disabled, it's deleted.
+    void initSearchLineEdit();
+
 public:
     KexiTabbedToolBarTabBar *customTabBar;
     QPointer<KexiMainMenu> mainMenu;
@@ -260,6 +265,7 @@ public:
     KActionCollection *ac;
     int createId;
     KToolBar *createWidgetToolBar;
+    QHBoxLayout *helpLayer;
 #ifdef KEXI_AUTORISE_TABBED_TOOLBAR
     //! Used for delayed tab raising
     int tabToRaise;
@@ -277,7 +283,7 @@ public:
     QGraphicsOpacityEffect tabBarOpacityEffect;
     int rolledUpIndex;
     KHelpMenu *helpMenu;
-    KexiSearchLineEdit *searchLineEdit;
+    KexiSearchLineEdit *searchLineEdit = nullptr;
     void setCurrentTab(const QString& name);
     void hideTab(const QString& name);
     void showTab(const QString& name);
