@@ -34,7 +34,6 @@
 #include <kexiutils/utils.h>
 #include <kexiutils/KexiAssistantPage.h>
 #include <kexiutils/KexiLinkWidget.h>
-#include <widget/KexiFileWidget.h>
 #include <widget/KexiConnectionSelectorWidget.h>
 #include <widget/KexiDBTitlePage.h>
 #include <widget/KexiProjectSelectorWidget.h>
@@ -47,7 +46,6 @@
 #include <KDbIdentifierValidator>
 
 #include <KIconLoader>
-#include <KRecentDirs>
 #include <KStandardGuiItem>
 
 #include <QDebug>
@@ -59,6 +57,7 @@
 
 class KexiServerDBNamePage : public QWidget, public Ui::KexiServerDBNamePage
 {
+    Q_OBJECT
 public:
     explicit KexiServerDBNamePage(QWidget* parent = 0);
 };
@@ -204,7 +203,7 @@ KexiProjectTitleSelectionPage::KexiProjectTitleSelectionPage(QWidget* parent)
             this, SLOT(titleTextChanged(QString)));
     fileHandler = new KexiStartupFileHandler(
         QUrl("kfiledialog:///OpenExistingOrCreateNewProject"),
-        KexiStartupFileHandler::SavingFileBasedDB,
+        KexiFileFilters::SavingFileBasedDB,
         contents->file_requester);
     fileHandler->setDefaultExtension("kexi");
     connect(fileHandler, SIGNAL(askForOverwriting(KexiContextMessage)),
@@ -322,7 +321,7 @@ KexiProjectConnectionSelectionPage::KexiProjectConnectionSelectionPage(QWidget*
                   xi18nc("@info",
                         "<para>Select database server's connection you wish to use to "
                         "create a new Kexi project.</para>"
-                        "<para>Here you may also add, edit or remove connections "
+                        "<para>Here you may also add, edit or delete connections "
                         "from the list.</para>"),
                   parent)
 {
@@ -332,10 +331,10 @@ KexiProjectConnectionSelectionPage::KexiProjectConnectionSelectionPage(QWidget*
         QVBoxLayout *lyr = new QVBoxLayout;
         connSelector = new KexiConnectionSelectorWidget(
             &Kexi::connset(),
-            "kfiledialog:///OpenExistingOrCreateNewProject",
-            KFileWidget::Saving);
+            QUrl("kfiledialog:///OpenExistingOrCreateNewProject"),
+            KexiConnectionSelectorWidget::Saving);
         lyr->addWidget(connSelector);
-        connSelector->showAdvancedConn();
+        connSelector->showAdvancedConnection();
         connect(connSelector, SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
                 this, SLOT(next()));
         connSelector->layout()->setContentsMargins(0, 0, 0, 0);
@@ -424,7 +423,6 @@ bool KexiProjectDatabaseNameSelectionPage::setConnection(KDbConnectionData* data
         m_projectSetToShow = new KexiProjectSet(m_assistant->messageHandler());
         KDbMessageGuard mg(m_projectSetToShow);
         if (!m_projectSetToShow->setConnectionData(data)) {
-            delete m_projectSetToShow;
             m_projectSetToShow = 0;
             return false;
         }
@@ -523,7 +521,7 @@ void KexiProjectDatabaseNameSelectionPage::overwriteActionTriggered()
 
 // ----
 
-class KexiNewProjectAssistant::Private
+class Q_DECL_HIDDEN KexiNewProjectAssistant::Private
 {
 public:
     explicit Private(KexiNewProjectAssistant *qq)
@@ -684,3 +682,5 @@ const QWidget* KexiNewProjectAssistant::calloutWidget() const
 {
     return currentPage()->nextButton();
 }
+
+#include "KexiNewProjectAssistant.moc"
