@@ -26,6 +26,10 @@
 #include <kexiutils/KexiContextMessage.h>
 #include <kexiutils/KexiFadeWidgetEffect.h>
 #include "KexiUserFeedbackAgent.h"
+#define KEXI_SKIP_SETUPPRIVATEICONSRESOURCE
+#define KEXI_SKIP_SETUPBREEZEICONTHEME
+#define KEXI_SKIP_REGISTERICONSRESOURCE
+#define KEXI_SKIP_REGISTERRESOURCE
 #include "KexiRegisterResource_p.h"
 
 #include <KColorScheme>
@@ -92,12 +96,12 @@ static QString uiPath(const QString &fname)
 
 static QString basePath()
 {
-    return QString("kexi/status/") + stableVersionStringDot0();
+    return QString(KEXI_BASE_PATH "/status");
 }
 
-static QString findFilename(const QString &guiFileName)
+static QString findFileName(const QString &guiFileName)
 {
-    QString result = locateFile(basePath() + '/' + guiFileName,
+    QString result = locateFile(QString(), basePath() + '/' + guiFileName,
                                 QStandardPaths::GenericDataLocation, QString());
     if (result.isEmpty()) { // last chance: file from the source tree
         result = QFileInfo(QFile::decodeName(CMAKE_CURRENT_SOURCE_DIR "/status/") + guiFileName)
@@ -109,7 +113,7 @@ static QString findFilename(const QString &guiFileName)
 
 // ---
 
-class KexiWelcomeStatusBarGuiUpdater::Private : public QObject
+class Q_DECL_HIDDEN KexiWelcomeStatusBarGuiUpdater::Private : public QObject
 {
     Q_OBJECT
 public:
@@ -313,7 +317,7 @@ private:
 
     void checkFile(const QByteArray &hash, const QString &remoteFname, QStringList *fileNamesToUpdate)
     {
-        QString localFname = findFilename(remoteFname);
+        QString localFname = findFileName(remoteFname);
         if (localFname.isEmpty()) {
             fileNamesToUpdate->append(remoteFname);
             qDebug() << "missing filename" << remoteFname << "- download it";
@@ -489,14 +493,14 @@ protected:
 
 // ---
 
-class KexiWelcomeStatusBar::Private
+class Q_DECL_HIDDEN KexiWelcomeStatusBar::Private
 {
 public:
     explicit Private(KexiWelcomeStatusBar* _q)
      : statusWidget(0), helpAction(0), shareAction(0), cancelAction(0),
        q(_q)
     {
-        rccFname = findFilename("status.rcc");
+        rccFname = findFileName("status.rcc");
         if (!rccFname.isEmpty())  {
             QResource::registerResource(rccFname);
         }
@@ -597,7 +601,7 @@ public:
 
     QWidget* loadGui(const QString &guiFileName, QWidget *parentWidget = 0)
     {
-        QString fname = findFilename(guiFileName);
+        QString fname = findFileName(guiFileName);
         if (fname.isEmpty()) {
             qWarning() << "filename" << fname << "not found";
             return 0;
@@ -929,7 +933,7 @@ void KexiWelcomeStatusBar::showDonation()
         return;
     }
     if (KMessageBox::Yes != KMessageBox::questionYesNo(this,
-       xi18nc("@info donate to the project", "<para><title>Kexi may be totally free, but its development is costly.</title><nl/>"
+       xi18nc("@info donate to the project", "<title>Kexi may be totally free, but its development is costly.</title>"
             "<para>Power, hardware, office space, internet access, traveling for meetings - everything costs.</para>"
             "<para>Direct donation is the easiest and fastest way to efficiently support the Kexi Project. "
             "Everyone, regardless of any degree of involvement can do so.</para>"
@@ -938,11 +942,14 @@ void KexiWelcomeStatusBar::showDonation()
             "expect new features, but you can also have an influence on what features are added!</para>"
             "<para>Currently we are accepting donations through <emphasis>BountySource</emphasis> (a funding platform "
             "for open-source software) using secure PayPal, Bitcoin and Google Wallet transfers.</para>"
-            "<para>Contact us at http://community.kde.org/Kexi/Contact for more information.</para>"
+            "<para>Contact us at <link url='https://community.kde.org/Kexi/Contact'>https://community.kde.org/Kexi/Contact</link> "
+            "for more information.</para>"
             "<para>Thanks for your support!</para>"),
        xi18n("Donate to the Project"),
        KGuiItem(xi18nc("@action:button Go to Donation", "Proceed to the Donation Web Page"), QIcon(":/icons/heart.png")),
-       KGuiItem(xi18nc("Do not donate now", "Not Now"))))
+       KGuiItem(xi18nc("Do not donate now", "Not Now")),
+       QString(),
+       KMessageBox::Notify | KMessageBox::AllowLink))
     {
         return;
     }
