@@ -30,7 +30,6 @@
 #include <kexitextmsghandler.h>
 #include <widget/kexicharencodingcombobox.h>
 #include <widget/kexiprjtypeselector.h>
-#include <widget/KexiFileWidget.h>
 #include <widget/KexiConnectionSelectorWidget.h>
 #include <widget/KexiProjectSelectorWidget.h>
 #include <widget/KexiDBTitlePage.h>
@@ -65,7 +64,7 @@
 
 using namespace KexiMigration;
 
-class ImportWizard::Private
+class Q_DECL_HIDDEN ImportWizard::Private
 {
 public:
 
@@ -161,7 +160,7 @@ ImportWizard::ImportWizard(QWidget *parent, QMap<QString, QString>* args)
 
     if (d->predefinedConnectionData) {
         // setup wizard for predefined server source
-        d->srcConn->showAdvancedConn();
+        d->srcConn->showAdvancedConnection();
         setAppropriate(d->srcConnPageItem, false);
         setAppropriate(d->srcDBPageItem, false);
     } else if (!d->predefinedDatabaseName.isEmpty()) {
@@ -169,8 +168,8 @@ ImportWizard::ImportWizard(QWidget *parent, QMap<QString, QString>* args)
         // (used when external project type was opened in Kexi, e.g. mdb file)
         setAppropriate(d->srcConnPageItem, false);
         setAppropriate(d->srcDBPageItem, false);
-        d->srcConn->showSimpleConn();
-        d->srcConn->setSelectedFileName(d->predefinedDatabaseName);
+        d->srcConn->showSimpleConnection();
+        d->srcConn->setSelectedFile(d->predefinedDatabaseName);
 
         #if 0
         //disable all prev pages except "welcome" page
@@ -217,7 +216,7 @@ void ImportWizard::parseArguments()
 QString ImportWizard::selectedSourceFileName() const
 {
     if (d->predefinedDatabaseName.isEmpty())
-        return d->srcConn->selectedFileName();
+        return d->srcConn->selectedFile();
 
     return d->predefinedDatabaseName;
 }
@@ -283,18 +282,20 @@ void ImportWizard::setupSrcConn()
     KexiUtils::setStandardMarginsAndSpacing(vbox);
 
     d->srcConn = new KexiConnectionSelectorWidget(&Kexi::connset(),
-                                                 "kfiledialog:///ProjectMigrationSourceDir",
-                                                 KFileWidget::Opening, d->srcConnPageWidget);
+                         QUrl("kfiledialog:///ProjectMigrationSourceDir"),
+                         KexiConnectionSelectorWidget::Opening, d->srcConnPageWidget);
 
     d->srcConn->hideConnectonIcon();
-    d->srcConn->showSimpleConn();
+    d->srcConn->showSimpleConnection();
+    connect(d->srcConn, &KexiConnectionSelectorWidget::connectionSelected,
+            this, &ImportWizard::sourceConnectionSelected);
 
-    QSet<QString> excludedFilters;
+    const QStringList excludedMimeTypes({
 //! @todo remove when support for kexi files as source prj is added in migration
-    excludedFilters += KDb::defaultFileBasedDriverMimeType();
-    excludedFilters += "application/x-kexiproject-shortcut";
-    excludedFilters += "application/x-kexi-connectiondata";
-    d->srcConn->fileWidget->setExcludedFilters(excludedFilters);
+        KDb::defaultFileBasedDriverMimeType(),
+        "application/x-kexiproject-shortcut",
+        "application/x-kexi-connectiondata"});
+    d->srcConn->setExcludedMimeTypes(excludedMimeTypes);
     vbox->addWidget(d->srcConn);
 
     d->srcConnPageItem = new KPageWidgetItem(d->srcConnPageWidget, xi18n("Select Location for Source Database"));
@@ -353,7 +354,7 @@ void ImportWizard::setupDstTitle()
     d->dstNewDBNameUrl = d->dstTitlePageWidget->file_requester;
     d->dstNewDBFileHandler = new KexiStartupFileHandler(
         QUrl("kfiledialog:///ProjectMigrationDestinationDir"),
-        KexiStartupFileHandler::SavingFileBasedDB,
+        KexiFileFilters::SavingFileBasedDB,
         d->dstTitlePageWidget->file_requester);
     d->dstNewDBNameLabel = new QLabel(xi18n("Destination project's name:"), d->dstTitlePageWidget);
     d->dstTitlePageWidget->formLayout->setWidget(2, QFormLayout::LabelRole, d->dstNewDBNameLabel);
@@ -389,17 +390,17 @@ void ImportWizard::setupDst()
     KexiUtils::setStandardMarginsAndSpacing(vbox);
 
     d->dstConn = new KexiConnectionSelectorWidget(&Kexi::connset(),
-                                                 "kfiledialog:///ProjectMigrationDestinationDir",
-                                                 KFileWidget::Saving, d->dstPageWidget);
+                         QUrl("kfiledialog:///ProjectMigrationDestinationDir"),
+                         KexiConnectionSelectorWidget::Saving, d->dstPageWidget);
     d->dstConn->hideHelpers();
 
     vbox->addWidget(d->dstConn);
     connect(d->dstConn, SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
             this, SLOT(next()));
 
-    d->dstConn->showSimpleConn();
+    d->dstConn->showSimpleConnection();
     //anyway, db files will be _saved_
-    d->dstConn->fileWidget->setMode(KexiFileWidget::SavingFileBasedDB);
+    d->dstConn->setFileMode(KexiFileFilters::SavingFileBasedDB);
     d->dstPageItem = new KPageWidgetItem(d->dstPageWidget, xi18n("Select Location for Destination Database Project"));
     addPage(d->dstPageItem);
 }
@@ -545,10 +546,8 @@ void ImportWizard::arriveSrcConnPage()
     in addition to just "open" */
     if (d->setupFileBasedSrcNeeded) {
         d->setupFileBasedSrcNeeded = false;
-        QSet<QString> additionalMimeTypes;
-        d->srcConn->fileWidget->setMode(KexiFileWidget::Opening);
-        d->srcConn->fileWidget->setAdditionalFilters(additionalMimeTypes);
-
+        d->srcConn->setFileMode(KexiFileFilters::Opening);
+        d->srcConn->setAdditionalMimeTypes(QStringList());
     }
 
     /*! @todo Support different file extensions based on MigrationDriver */
@@ -616,7 +615,7 @@ void ImportWizard::arriveDstPage()
         return;
     }
     else {
-        d->dstConn->showAdvancedConn();
+        d->dstConn->showAdvancedConnection();
     }
     d->dstPageWidget->show();
 }
@@ -635,7 +634,7 @@ void ImportWizard::arriveImportingPage()
                                    "determine this for you."*/));
 
     //temp. hack for MS Access driver only
-//! @todo for other databases we will need KexiMigration::Conenction
+//! @todo for other databases we will need KexiMigration::Connection
 //!       and KexiMigration::Driver classes
     bool showOptions = false;
     if (fileBasedSrcSelected()) {
@@ -644,9 +643,7 @@ void ImportWizard::arriveImportingPage()
         if (sourceDriver) {
             showOptions = !result.error()
                           && sourceDriver->propertyValue("source_database_has_nonunicode_encoding").toBool();
-            KexiMigration::Data *data = sourceDriver->data();
-            sourceDriver->setData(0);
-            delete data;
+            sourceDriver->setData(nullptr);
         }
     }
     if (showOptions)
@@ -757,6 +754,7 @@ KexiMigrate* ImportWizard::prepareImport(Kexi::ObjectStatus& result)
 
     // Set up destination connection data
     KDbConnectionData *cdata = 0;
+    QScopedPointer<KDbConnectionData> cdataDeleter;
     QString dbname;
     if (!result.error()) {
         if (d->dstConn->selectedConnectionData()) {
@@ -769,6 +767,7 @@ KexiMigrate* ImportWizard::prepareImport(Kexi::ObjectStatus& result)
             //file-based project
             qDebug() << "File Destination...";
             cdata = new KDbConnectionData();
+            cdataDeleter.reset(cdata); // ownership won't be transferred
             cdata->setCaption(d->dstNewDBTitleLineEdit->text());
             cdata->setDriverId(KDb::defaultFileBasedDriverId());
             dbname = d->dstTitlePageWidget->file_requester->url().toLocalFile();
@@ -821,7 +820,7 @@ KexiMigrate* ImportWizard::prepareImport(Kexi::ObjectStatus& result)
         }
 
         KexiMigration::Data* md = new KexiMigration::Data();
-        md->destination = new KexiProjectData(*cdata, dbname);
+        md->setDestinationProjectData(new KexiProjectData(*cdata, dbname));
         if (fileBasedSrcSelected()) {
             KDbConnectionData* conn_data = new KDbConnectionData();
             conn_data->setDatabaseName(selectedSourceFileName());
@@ -839,7 +838,7 @@ KexiMigrate* ImportWizard::prepareImport(Kexi::ObjectStatus& result)
                 md->sourceName = d->srcProjectSelector->selectedProjectData()->databaseName();
             //! @todo Aah, this is so C-like. Move to performImport().
         }
-        md->keepData = keepData;
+        md->setShouldCopyData(keepData);
         sourceDriver->setData(md);
         return sourceDriver;
     }
@@ -866,7 +865,7 @@ tristate ImportWizard::import()
             return false;
         }
 
-        qDebug() << sourceDriver->data()->destination->databaseName();
+        qDebug() << sourceDriver->data()->destinationProjectData()->databaseName();
         qDebug() << "Performing import...";
     }
 
@@ -876,7 +875,8 @@ tristate ImportWizard::import()
                         xi18nc("@info (don't add tags around %1, it's done already)",
                                "<para>Database %1 already exists.</para>"
                                "<para>Do you want to replace it with a new one?</para>",
-                               KexiUtils::localizedStringToHtmlSubstring(sourceDriver->data()->destination->infoString())),
+                               KexiUtils::localizedStringToHtmlSubstring(
+                                   sourceDriver->data()->destinationProjectData()->infoString())),
                 0, KGuiItem(xi18nc("@action:button Replace Database", "&Replace")), KStandardGuiItem::no()))
         {
             return cancelled;
@@ -891,8 +891,8 @@ tristate ImportWizard::import()
         if (d->args) {
             d->args->insert("destinationDatabaseName",
                             fileBasedDstSelected()
-                            ? sourceDriver->data()->destination->connectionData()->databaseName()
-                            : sourceDriver->data()->destination->databaseName());
+                            ? sourceDriver->data()->destinationProjectData()->connectionData()->databaseName()
+                            : sourceDriver->data()->destinationProjectData()->databaseName());
             QString destinationConnectionShortcut;
             if (d->dstConn->selectedConnectionData()) {
                 destinationConnectionShortcut
@@ -958,7 +958,7 @@ void ImportWizard::next()
         if (!import || d->migrateManager.result().isError()) {
             QString dbname;
             if (fileBasedSrcSelected())
-                dbname = selectedSourceFileName();
+                dbname = QDir::toNativeSeparators(selectedSourceFileName());
             else
                 dbname = conndata ? conndata->toUserVisibleString() : QString();
             KMessageBox::error(this,
@@ -996,8 +996,8 @@ void ImportWizard::next()
         }
     } else if (currentPage() == d->dstTitlePageItem) {
         if (fileBasedDstSelected()) {
-            if (QFileInfo(d->dstNewDBNameUrl->url().toLocalFile()).exists()) {
-                if (!KexiFileWidget::askForOverwriting(d->dstNewDBNameUrl->url().toLocalFile(), this)) {
+            if (QFileInfo::exists(d->dstNewDBNameUrl->url().toLocalFile())) {
+                if (!KexiUtils::askForFileOverwriting(d->dstNewDBNameUrl->url().toLocalFile(), this)) {
                     return;
                 }
             }
@@ -1120,12 +1120,15 @@ void ImportWizard::helpClicked()
 
 void ImportWizard::slotOptionsButtonClicked()
 {
-    QPointer<OptionsDialog> dlg = new OptionsDialog(selectedSourceFileName(), d->sourceDBEncoding, this);
-    if (QDialog::Accepted == dlg->exec()) {
-        if (d->sourceDBEncoding != dlg->encodingComboBox()->selectedEncoding()) {
-            d->sourceDBEncoding = dlg->encodingComboBox()->selectedEncoding();
-        }
+    OptionsDialog dlg(selectedSourceFileName(), d->sourceDBEncoding, this);
+    if (QDialog::Accepted == dlg.exec()) {
+        d->sourceDBEncoding = dlg.encodingComboBox()->selectedEncoding();
     }
-    delete dlg;
 }
 
+void ImportWizard::sourceConnectionSelected(bool selected)
+{
+    if (selected) {
+        next();
+    }
+}
