@@ -23,14 +23,44 @@
 
 using namespace KexiMigration;
 
+class Q_DECL_HIDDEN Data::Private
+{
+public:
+    Private() {}
+
+    KexiProjectData *destinationProjectData = nullptr;
+
+    //! @c true if not only structure should be migrated but also data
+    bool shouldCopyData = true;
+};
+
 Data::Data()
-        : source(0)
-        , destination(0)
+    : source(nullptr)
+    , d(new Private)
 {
 }
 
 Data::~Data()
 {
+    delete d;
+}
+
+KexiProjectData* Data::destinationProjectData()
+{
+    return d->destinationProjectData;
+}
+
+const KexiProjectData* Data::destinationProjectData() const
+{
+    return d->destinationProjectData;
+}
+
+void Data::setDestinationProjectData(KexiProjectData* destinationProjectData)
+{
+    if (d->destinationProjectData && d->destinationProjectData != destinationProjectData) {
+        delete d->destinationProjectData;
+    }
+    d->destinationProjectData = destinationProjectData;
 }
 
 QString Data::sourceDatabaseInfoString() const
@@ -38,3 +68,13 @@ QString Data::sourceDatabaseInfoString() const
     return source ? KexiProjectData::infoString(sourceName, *source).toString(Kuit::PlainText)
                   : QString();
 }
+
+bool Data::shouldCopyData() const
+{
+    return d->shouldCopyData;
+}
+
+void Data::setShouldCopyData(bool set)
+{
+    d->shouldCopyData = set;
+}
