@@ -54,9 +54,13 @@
 #define MDB_NO_BACKENDS 1
 #define MDB_NO_STATS 1
 
+#ifdef _MSC_VER
+#define MDB_DEPRECATED(type, funcname) type funcname
+#else
 // Theses 2 atrbutes are not supported by all compilers:
 // M$VC see http://stackoverflow.com/questions/1113409/attribute-constructor-equivalent-in-vc
 #define MDB_DEPRECATED(type, funcname) type __attribute__((deprecated)) funcname
+#endif
 #define MDB_CONSTRUCTOR(funcname) void __attribute__((constructor)) funcname()
 
 enum {
