@@ -78,13 +78,19 @@ mdb_write_pg(MdbHandle *mdb, unsigned long pg)
 	struct stat status;
 	off_t offset = pg * mdb->fmt->pg_size;
 
-	fstat(mdb->f->fd, &status);
+	if (fstat(mdb->f->fd, &status) != 0) {
+		perror("fstat");
+		return 0;
+	}
 	/* is page beyond current size + 1 ? */
 	if ((size_t)status.st_size < (offset + mdb->fmt->pg_size)) {
 		fprintf(stderr,"offset %jd is beyond EOF\n",(intmax_t)offset);
 		return 0;
 	}
-	lseek(mdb->f->fd, offset, SEEK_SET);
+	if (lseek(mdb->f->fd, offset, SEEK_SET) == -1) {
+		perror("lseek");
+		return 0;
+	}
 	len = write(mdb->f->fd,mdb->pg_buf,mdb->fmt->pg_size);
 	if (len==-1) {
 		perror("write");
