@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
-   Copyright (C) 2004-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2017 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@
 #include <formeditor/WidgetTreeWidget.h>
 #include <kexi.h>
 #include <kexi_global.h>
-//! @todo KEXI3 Port #include <kexidragobjects.h>
+#include <kexidragobjects.h>
 #include <widget/kexiqueryparameters.h>
 #include <kexiutils/utils.h>
 #include <KexiMainWindowIface.h>
@@ -36,7 +36,9 @@
 #include "kexiformscrollview.h"
 #include "kexidatasourcepage.h"
 #include "kexiformmanager.h"
-#include "widgets/kexidbautofield.h"
+#ifdef KEXI_AUTOFIELD_FORM_WIDGET_SUPPORT
+#include "kexidbautofield.h"
+#endif
 
 #include <KDbConnection>
 #include <KDbCursor>
@@ -58,7 +60,7 @@
 
 //! @todo #define KEXI_SHOW_SPLITTER_WIDGET
 
-class KexiFormView::Private
+class Q_DECL_HIDDEN KexiFormView::Private
 {
 public:
     Private()
@@ -122,7 +124,7 @@ KexiFormView::KexiFormView(QWidget *parent, bool dbAware)
     d->scrollView = new KexiFormScrollView(         // will be added to layout
         this, viewMode() == Kexi::DataViewMode);   // in KexiDataAwareView::init()
 
-    initForm();
+    (void)initForm();
 
     if (viewMode() == Kexi::DesignViewMode) {
         connect(form(), SIGNAL(propertySetSwitched()), this, SLOT(slotPropertySetSwitched()));
@@ -224,7 +226,7 @@ KexiFormView::setForm(KFormDesigner::Form *f)
     d->form = f;
 }
 
-void KexiFormView::initForm()
+bool KexiFormView::initForm()
 {
     d->dbform = new KexiDBForm(d->scrollView->widget(), d->scrollView);
     if (viewMode() == Kexi::DataViewMode) {
@@ -284,12 +286,14 @@ void KexiFormView::initForm()
 #ifndef KEXI_NO_FORM_DATASOURCE_WIZARD
         QDomDocument dom;
         formPart()->generateForm(fields, dom);
-        KFormDesigner::FormIO::loadFormFromDom(form(), d->dbform, dom);
+        KFormDesigner::FormIO::loadFormFromDom(form(), d->dbform, &dom);
         //! @todo handle errors
 #endif
     }
     else {
-        loadForm();
+        if (!loadForm()) {
+            return false;
+        }
     }
 
     if (form()->autoTabStops())
@@ -325,10 +329,12 @@ void KexiFormView::initForm()
     if (!newForm && viewMode() == Kexi::DesignViewMode) {
         form()->clearUndoStack();
     }
+    return true;
 }
 
 void KexiFormView::updateAutoFieldsDataSource()
 {
+#ifdef KEXI_AUTOFIELD_FORM_WIDGET_SUPPORT
 //! @todo call this when form's data source is changed
     //update autofields:
     //-inherit captions
@@ -338,7 +344,8 @@ void KexiFormView::updateAutoFieldsDataSource()
     QString dataSourcePartClassString(d->dbform->dataSourcePluginId());
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
     KDbTableOrQuerySchema tableOrQuery(
-        conn, dataSourceString.toLatin1(), dataSourcePartClassString == "org.kexi-project.table");
+        conn, dataSourceString.toLatin1(), dataSourcePartClassString == "org.kexi-project.table"
+        ? KDbTableOrQuerySchema::Type::Table :: KDbTableOrQuerySchema::Type::Query);
     if (!tableOrQuery.table() && !tableOrQuery.query())
         return;
     foreach (KFormDesigner::ObjectTreeItem *item, *form()->objectTree()->hash()) {
@@ -350,6 +357,7 @@ void KexiFormView::updateAutoFieldsDataSource()
             }
         }
     }
+#endif
 }
 
 void KexiFormView::updateValuesForSubproperties()
@@ -362,8 +370,10 @@ void KexiFormView::updateValuesForSubproperties()
     QString dataSourceString(d->dbform->dataSource());
     QString dataSourcePartClassString(d->dbform->dataSourcePluginId());
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-    KDbTableOrQuerySchema tableOrQuery(
-        conn, dataSourceString.toLatin1(), dataSourcePartClassString == "org.kexi-project.table");
+    KDbTableOrQuerySchema tableOrQuery(conn, dataSourceString.toLatin1(),
+                                       dataSourcePartClassString == "org.kexi-project.table"
+                                           ? KDbTableOrQuerySchema::Type::Table
+                                           : KDbTableOrQuerySchema::Type::Query);
     if (!tableOrQuery.table() && !tableOrQuery.query())
         return;
 
@@ -424,30 +434,39 @@ static void setUnsavedBLOBIdsForDataViewMode(
   }
 }
 
-void
-KexiFormView::loadForm()
+bool KexiFormView::loadForm()
 {
 //! @todo also load d->resizeMode
     //qDebug() << "Loading the form with id" << window()->id();
     // If we are previewing the Form, use the tempData instead of the form stored in the db
     if (viewMode() == Kexi::DataViewMode && !tempData()->tempForm.isNull()) {
-        KFormDesigner::FormIO::loadFormFromString(form(), d->dbform, &tempData()->tempForm);
+        if (!KFormDesigner::FormIO::loadFormFromString(form(), d->dbform, tempData()->tempForm)) {
+            return false;
+        }
         setUnsavedBLOBIdsForDataViewMode(d->dbform, tempData()->unsavedLocalBLOBsByName);
         updateAutoFieldsDataSource();
         updateValuesForSubproperties();
-        return;
+        return true;
     }
 
-    // normal load
-    QString data;
-    loadDataBlock(&data);
-    KFormDesigner::FormIO::loadFormFromString(form(), d->dbform, &data);
+    if (!window()->neverSaved()) {
+        // normal load
+        QString data;
+        if (!loadDataBlock(&data)) {
+            return false;
+        }
+        if (!KFormDesigner::FormIO::loadFormFromString(form(), d->dbform, data)) {
+            return false;
+        }
+        tempData()->setDataSource(d->dbform->dataSourcePluginId(), d->dbform->dataSource());
+    }
 
     //"autoTabStops" property is loaded -set it within the form tree as well
     form()->setAutoTabStops(d->dbform->autoTabStops());
 
     updateAutoFieldsDataSource();
     updateValuesForSubproperties();
+    return true;
 }
 
 void
@@ -517,7 +536,9 @@ tristate KexiFormView::afterSwitchFrom(Kexi::ViewMode mode)
     if ((mode == Kexi::DesignViewMode) && viewMode() == Kexi::DataViewMode) {
         // The form may have been modified, so we must recreate the preview
         delete d->dbform; // also deletes form()
-        initForm();
+        if (!initForm()) {
+            return false;
+        }
 
         //reset position
         d->scrollView->horizontalScrollBar()->setValue(0);
@@ -553,7 +574,7 @@ tristate KexiFormView::afterSwitchFrom(Kexi::ViewMode mode)
                 if (iface && iface->columnInfo() && !iface->isReadOnly()
                         /*! @todo add option for skipping autoincremented fields */
                         /* also skip autoincremented fields:*/
-                        && !iface->columnInfo()->field->isAutoIncrement())
+                        && !iface->columnInfo()->field()->isAutoIncrement())
                 {
                     break;
                 }
@@ -689,17 +710,18 @@ void KexiFormView::initDataSource()
             deleteQuery();
         }
         else {
-            qDebug() << d->query->parameters();
+            qDebug() << d->query->parameters(conn);
             // like in KexiQueryView::executeQuery()
             QList<QVariant> params;
             {
                 KexiUtils::WaitCursorRemover remover;
-                params = KexiQueryParameters::getParameters(this, *conn->driver(), d->query, &ok);
+                params = KexiQueryParameters::getParameters(this, conn, d->query, &ok);
             }
             if (ok) //input cancelled
                 d->cursor = conn->executeQuery(d->query, params);
         }
-        d->scrollView->invalidateDataSources(invalidSources, d->query);
+        d->scrollView->invalidateDataSources(
+            invalidSources, d->cursor ? d->cursor->connection() : nullptr, d->query);
         ok = d->cursor != 0;
     }
 
@@ -1043,20 +1065,29 @@ KexiFormView::updateDataSourcePage()
 {
     if (viewMode() == Kexi::DesignViewMode) {
         KPropertySet *set = form()->propertySet();
-        const QString dataSourcePartClass = set->propertyValue("dataSourcePartClass").toString();
+        QString dataSourcePartClass = set->propertyValue("dataSourcePartClass").toString();
         const QString dataSource = set->propertyValue("dataSource").toString();
         formPart()->dataSourcePage()->setFormDataSource(dataSourcePartClass, dataSource);
+        if (dataSourcePartClass.isEmpty()
+            && !formPart()->dataSourcePage()->selectedPluginId().isEmpty())
+        {
+            set->property("dataSourcePartClass")
+                .setValue(formPart()->dataSourcePage()->selectedPluginId(),
+                          KProperty::ValueOption::IgnoreOld);
+        }
     }
 }
 
 void
 KexiFormView::slotHandleDragMoveEvent(QDragMoveEvent* e)
 {
-    Q_UNUSED(e);
-/*! @todo KEXI3 Port kexidragobjects.cpp
+#ifdef KEXI_AUTOFIELD_FORM_WIDGET_SUPPORT
     if (KexiFieldDrag::canDecode(e)) {
         e->setAccepted(true);
-    }*/
+    }
+#else
+    Q_UNUSED(e);
+#endif
 }
 
 void
@@ -1092,7 +1123,9 @@ KexiFormView::insertAutoFields(const QString& sourcePartClass, const QString& so
 
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
     KDbTableOrQuerySchema tableOrQuery(conn, sourceName.toLatin1(),
-                                            sourcePartClass == "org.kexi-project.table");
+                                       sourcePartClass == "org.kexi-project.table"
+                                       ? KDbTableOrQuerySchema::Type::Table
+                                       : KDbTableOrQuerySchema::Type::Query);
     if (!tableOrQuery.table() && !tableOrQuery.query()) {
         qWarning() << "no such table/query" << sourceName;
         return;
