@@ -38,6 +38,7 @@
 //! @internal A validator used for read only flag to disable editing
 class KexiDBLineEdit_ReadOnlyValidator : public QValidator
 {
+    Q_OBJECT
 public:
     KexiDBLineEdit_ReadOnlyValidator(QObject * parent)
             : QValidator(parent) {
@@ -55,6 +56,7 @@ public:
 //! A style proxy overriding KexiDBLineEdit style
 class KexiDBLineEditStyle : public QProxyStyle
 {
+    Q_OBJECT
 public:
     explicit KexiDBLineEditStyle(const QString &baseStyleName)
         : QProxyStyle(baseStyleName), indent(0)
@@ -285,10 +287,10 @@ void KexiDBLineEdit::clear()
         QLineEdit::clear();
 }
 
-void KexiDBLineEdit::setColumnInfo(KDbQueryColumnInfo* cinfo)
+void KexiDBLineEdit::setColumnInfo(KDbConnection *conn, KDbQueryColumnInfo* cinfo)
 {
-    KexiFormDataItemInterface::setColumnInfo(cinfo);
-    m_textFormatter.setField( cinfo ? cinfo->field : 0 );
+    KexiFormDataItemInterface::setColumnInfo(conn, cinfo);
+    m_textFormatter.setField(cinfo ? cinfo->field() : nullptr);
     KexiTextFormatter::OverrideDecimalPlaces overrideDecimalPlaces;
     overrideDecimalPlaces.enabled = true;
     overrideDecimalPlaces.value = -1; // all possible digits
@@ -300,7 +302,7 @@ void KexiDBLineEdit::setColumnInfo(KDbQueryColumnInfo* cinfo)
 
 //! @todo handle input mask (via QLineEdit::setInputMask()) using a special KDbFieldInputMask class
     delete m_readWriteValidator;
-    KDbFieldValidator* fieldValidator = new KDbFieldValidator(*cinfo->field, this);
+    KDbFieldValidator* fieldValidator = new KDbFieldValidator(*cinfo->field(), this);
     if (m_internalReadOnly) {
         m_readWriteValidator = fieldValidator;
     }
@@ -324,7 +326,7 @@ void KexiDBLineEdit::paintEvent(QPaintEvent *pe)
         if (dataItemIface && !dataItemIface->dataSource().isEmpty() && !formWidget->editingMode()) {
             // draw "data source tag" icon
             QPainter p(this);
-            QStyleOptionFrameV2 option;
+            QStyleOptionFrame option;
             initStyleOption(&option);
 
             int leftMargin, topMargin, rightMargin, bottomMargin;
@@ -458,3 +460,5 @@ void KexiDBLineEdit::setDataSourcePluginId(const QString &pluginId)
     updateTextForDataSource();
 }
 
+#include "kexidblineedit.moc"
+
