@@ -32,8 +32,8 @@ public:
     virtual ~KexiCsvImportExportPlugin();
 
     /*! Reimplemented to return wizard object. */
-    virtual QWidget *createWidget(const char* widgetClass,
-                                  QWidget *parent, const char *objName = 0, QMap<QString, QString>* args = 0);
+    QWidget *createWidget(const char *widgetClass, QWidget *parent, const char *objName = nullptr,
+                          QMap<QString, QString> *args = nullptr) override Q_REQUIRED_RESULT;
 
     /*! Reimplemented to execute a command \a commandName (nonvisual). The result are put into the \a args. */
     virtual bool executeCommand(const char* commandName, QMap<QString, QString>* args = 0);
