@@ -1,9 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2005-2017 Jarosław Staniek <staniek@kde.org>
    Copyright (C) 2012 Oleg Kukharchuk <oleg.kuh@gmail.com>
 
-   This work is based on kspread/dialogs/kspread_dlg_csv.cc
-   and could be merged back with Calligra Libraries.
+   This work is based on kspread/dialogs/kspread_dlg_csv.cc.
 
    Copyright (C) 2002-2003 Norbert Andres <nandres@web.de>
    Copyright (C) 2002-2003 Ariya Hidayat <ariya@kde.org>
@@ -39,19 +38,19 @@
 #include <core/kexiguimsghandler.h>
 #include <core/KexiWindow.h>
 #include <widget/kexicharencodingcombobox.h>
-#include <widget/KexiFileWidget.h>
-#include <kexiutils/KexiCommandLinkButton.h>
 #include <widget/KexiNameWidget.h>
 #include <widget/navigator/KexiProjectNavigator.h>
 #include <widget/navigator/KexiProjectTreeView.h>
 #include <widget/fields/KexiFieldListView.h>
 #include <widget/fields/KexiFieldListModel.h>
+#include <widget/KexiFileWidgetInterface.h>
 #include "kexicsvwidgets.h"
 #include <kexi_global.h>
 
 #include <KDbObjectNameValidator>
 #include <KDbConnection>
 #include <KDbTableOrQuerySchema>
+#include <KDbTransactionGuard>
 
 #include <KMessageBox>
 #include <KCharsets>
@@ -60,6 +59,7 @@
 #include <KSharedConfig>
 #include <KGuiItem>
 
+#include <QDir>
 #include <QSpinBox>
 #include <QCheckBox>
 #include <QClipboard>
@@ -87,12 +87,14 @@
 #include <QProgressBar>
 #include <QDialog>
 #include <QDebug>
+#include <QRadioButton>
 
 #define _IMPORT_ICON koIconNeededWithSubs("change to file_import or so", "file_import","table")
 
 //! @internal An item delegate for KexiCSVImportDialog's table view
 class KexiCSVImportDialogItemDelegate : public QStyledItemDelegate
 {
+    Q_OBJECT
 public:
     KexiCSVImportDialogItemDelegate(QObject *parent = 0);
 
@@ -167,7 +169,7 @@ static bool shouldSaveRow(int row, bool firstRowForFieldNames)
 
 // --
 
-class KexiCSVImportDialog::Private
+class Q_DECL_HIDDEN KexiCSVImportDialog::Private
 {
 public:
     Private()
@@ -260,7 +262,6 @@ KexiCSVImportDialog::KexiCSVImportDialog(Mode mode, QWidget * parent)
         m_stringI18nNo(xi18n("no")),
         m_stringFalse("false"),
         m_stringI18nFalse(xi18n("false")),
-        m_newTable(false),
         m_partItemForSavedTable(0),
         m_importInProgress(false),
         m_importCanceled(false),
@@ -288,7 +289,7 @@ KexiCSVImportDialog::KexiCSVImportDialog(Mode mode, QWidget * parent)
     m_minimumYearFor100YearSlidingWindow = importExportGroup.readEntry(
         "MinimumYearFor100YearSlidingWindow", MINIMUM_YEAR_FOR_100_YEAR_SLIDING_WINDOW);
 
-    m_pkIcon = SmallIcon(KexiIconName("database-key"));
+    m_pkIcon = KexiSmallIcon("database-key");
 
     if (m_mode == File) {
         createFileOpenPage();
@@ -388,16 +389,11 @@ void KexiCSVImportDialog::next()
     KPageWidgetItem *curPage = currentPage();
 
     if (curPage == m_openFilePage) {
-        m_fname = m_openFileWidget->highlightedFile();
-        if (m_openFileWidget->checkSelectedFile()) {
-            m_fname = m_openFileWidget->highlightedFile();
+        if (m_fileIface->checkSelectedFile()) {
+            m_fname = m_fileIface->selectedFile();
         } else {
             return;
         }
-        if (m_fname.isEmpty()) {
-            KMessageBox::sorry(this, xi18nc("@info", "Select source filename."));
-            return;
-        }
         if (!openData()) {
             return;
         }
@@ -411,6 +407,14 @@ void KexiCSVImportDialog::next()
                 xi18n("Data set contains no rows. Do you want to import empty table?")))
             return;
         }
+    } else if (curPage == m_saveMethodPage) {
+        if (m_newTableOption->isChecked()) {
+            m_tableNameWidget->setCurrentIndex(0);
+            m_newTableWidget->setFocus();
+        } else {
+            m_tableNameWidget->setCurrentIndex(1);
+            m_tablesList->setFocus();
+        }
     } else if (curPage == m_tableNamePage) {
         KexiGUIMessageHandler msg;
         KexiProject *project = KexiMainWindowIface::global()->project();
@@ -424,7 +428,7 @@ void KexiCSVImportDialog::next()
             msg.showErrorMessage(KDbMessageHandler::Error, xi18n("No database connection available."));
             return;
         }
-        if (m_newTable) {
+        if (m_newTableOption->isChecked()) {
             m_partItemForSavedTable->setCaption(m_newTableWidget->captionText());
             m_partItemForSavedTable->setName(m_newTableWidget->nameText());
 
@@ -461,18 +465,16 @@ void KexiCSVImportDialog::slotShowSchema(KexiPart::Item *item)
     }
 
     nextButton()->setEnabled(true);
-    KDbTableOrQuerySchema *tableOrQuery = new KDbTableOrQuerySchema(
-            KexiMainWindowIface::global()->project()->dbConnection(),
-            item->identifier()
-            );
+    KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
+    KDbTableOrQuerySchema *tableOrQuery = new KDbTableOrQuerySchema(conn, item->identifier());
     m_tableCaptionLabel->setText(tableOrQuery->captionOrName());
     m_tableNameLabel->setText(tableOrQuery->name());
-    m_recordCountLabel->setText(QString::number(KDb::recordCount(tableOrQuery)));
-    m_colCountLabel->setText(QString::number(tableOrQuery->fieldCount()));
+    m_recordCountLabel->setText(QString::number(conn->recordCount(tableOrQuery)));
+    m_colCountLabel->setText(QString::number(tableOrQuery->fieldCount(conn)));
 
     delete m_fieldsListModel;
     m_fieldsListModel = new KexiFieldListModel(m_fieldsListView, ShowDataTypes);
-    m_fieldsListModel->setSchema(tableOrQuery);
+    m_fieldsListModel->setSchema(conn, tableOrQuery);
     m_fieldsListView->setModel(m_fieldsListModel);
     m_fieldsListView->header()->resizeSections(QHeaderView::ResizeToContents);
 }
@@ -489,7 +491,7 @@ void KexiCSVImportDialog::slotCurrentPageChanged(KPageWidgetItem *page, KPageWid
     backButton()->setEnabled(page == m_openFilePage ? false : true);
 
     if (page == m_saveMethodPage && prev == m_tableNamePage && m_partItemForSavedTable) {
-        if (m_newTable) {
+        if (m_newTableOption->isChecked()) {
             KexiMainWindowIface::global()->project()->deleteUnstoredItem(m_partItemForSavedTable);
         }
         m_partItemForSavedTable = 0;
@@ -525,9 +527,9 @@ void KexiCSVImportDialog::slotCurrentPageChanged(KPageWidgetItem *page, KPageWid
             m_loadingProgressDlg->hide();
         m_tableView->setFocus();
     } else if (page == m_saveMethodPage) {
-        m_newTableButton->setFocus();
+        m_newTableOption->setFocus();
     } else if (page == m_tableNamePage) {
-        if (m_newTable && !m_partItemForSavedTable) {
+        if (m_newTableOption->isChecked() && !m_partItemForSavedTable) {
             KexiGUIMessageHandler msg;
             KexiProject *project = KexiMainWindowIface::global()->project();
             //get suggested name based on the file name
@@ -557,7 +559,7 @@ void KexiCSVImportDialog::slotCurrentPageChanged(KPageWidgetItem *page, KPageWid
             m_newTableWidget->setNameText(m_partItemForSavedTable->name());
             m_newTableWidget->captionLineEdit()->setFocus();
             m_newTableWidget->captionLineEdit()->selectAll();
-        } else if (!m_newTable) {
+        } else if (!m_newTableOption->isChecked()) {
             KexiPart::Item *i = m_tablesList->selectedPartItem();
             if (!i) {
                 nextButton()->setEnabled(false);
@@ -575,15 +577,12 @@ void KexiCSVImportDialog::slotCurrentPageChanged(KPageWidgetItem *page, KPageWid
 
 void KexiCSVImportDialog::createFileOpenPage()
 {
-    m_openFileWidget = new KexiFileWidget(
-        QUrl("kfiledialog:///CSVImportExport"), //startDir
-        KexiFileWidget::Custom | KexiFileWidget::Opening,
-        this);
-    m_openFileWidget->setObjectName("m_openFileWidget");
-    m_openFileWidget->setAdditionalFilters(csvMimeTypes().toSet());
-    m_openFileWidget->setDefaultExtension("csv");
-    connect(m_openFileWidget, SIGNAL(fileSelected(QUrl)), this, SLOT(next()));
-    m_openFilePage = new KPageWidgetItem(m_openFileWidget, xi18n("Select Import Filename"));
+    m_fileIface = KexiFileWidgetInterface::createWidget(QUrl("kfiledialog:///CSVImportExport"),
+                                                        KexiFileFilters::CustomOpening, this);
+    m_fileIface->setAdditionalMimeTypes(csvMimeTypes());
+    m_fileIface->setDefaultExtension("csv");
+    m_fileIface->connectFileSelectedSignal(this, SLOT(next()));
+    m_openFilePage = new KPageWidgetItem(m_fileIface->widget(), xi18n("Select Import Filename"));
     addPage(m_openFilePage);
 }
 
@@ -605,7 +604,7 @@ void KexiCSVImportDialog::createOptionsPage()
 
     // Delimiter: comma, semicolon, tab, space, other
     m_delimiterWidget = new KexiCSVDelimiterWidget(true /*lineEditOnBottom*/, page);
-    glyr->addWidget(m_delimiterWidget, 1, 0, 2, 1);
+    glyr->addWidget(m_delimiterWidget, 1, 0, 1, 1);
 
     QLabel *delimiterLabel = new QLabel(xi18n("Delimiter:"), page);
     delimiterLabel->setBuddy(m_delimiterWidget);
@@ -702,14 +701,13 @@ void KexiCSVImportDialog::createImportMethodPage()
     m_saveMethodWidget = new QWidget(this);
     QGridLayout *l = new QGridLayout(m_saveMethodWidget);
 
-    m_newTableButton = new KexiCommandLinkButton(xi18nc("@action:button", "New table"),
-            xi18nc("CSV import: data will be appended to a new table", "Data will be appended to a new table"), m_saveMethodWidget);
-    m_newTableButton->setArrowVisible(true);
-    m_existentTableButton = new KexiCommandLinkButton(xi18nc("@action:button", "Existing table"),
-            xi18nc("CSV import: data will be appended to existing table", "Data will be appended to existing table"), m_saveMethodWidget);
-    m_existentTableButton->setArrowVisible(true);
-    l->addWidget(m_newTableButton, 0, 0, 1, 1);
-    l->addWidget(m_existentTableButton, 1, 0, 1, 1);
+    m_newTableOption = new QRadioButton(
+        xi18nc("@option:check CSV import: data will be appended to a new table", "&New table"));
+    m_newTableOption->setChecked(true);
+    m_existingTableOption = new QRadioButton(
+        xi18nc("@option:check CSV import: data will be appended to existing table", "&Existing table"));
+    l->addWidget(m_newTableOption, 0, 0, 1, 1);
+    l->addWidget(m_existingTableOption, 1, 0, 1, 1);
 
     QSpacerItem *hSpacer = new QSpacerItem(200, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);
     QSpacerItem *vSpacer = new QSpacerItem(20, 200, QSizePolicy::Minimum, QSizePolicy::Expanding);
@@ -717,11 +715,8 @@ void KexiCSVImportDialog::createImportMethodPage()
     l->addItem(hSpacer, 1, 1, 1, 1);
     l->addItem(vSpacer, 2, 0, 1, 1);
 
-    m_saveMethodPage = new KPageWidgetItem(m_saveMethodWidget, xi18n("Choose Method of Saving Imported Data"));
+    m_saveMethodPage = new KPageWidgetItem(m_saveMethodWidget, xi18n("Choose Destination for Imported Data"));
     addPage(m_saveMethodPage);
-
-    connect(m_newTableButton, SIGNAL(clicked()), this, SLOT(slotCommandLinkClicked()));
-    connect(m_existentTableButton, SIGNAL(clicked()), this, SLOT(slotCommandLinkClicked()));
 }
 
 void KexiCSVImportDialog::createTableNamePage()
@@ -814,19 +809,10 @@ void KexiCSVImportDialog::createImportPage()
     l->addStretch(1);
     m_importingProgressBar->hide();
     m_importProgressLabel->hide();
-    m_importPage = new KPageWidgetItem(m_importWidget, xi18n("Importing..."));
+    m_importPage = new KPageWidgetItem(m_importWidget, xi18n("Ready to Import"));
     addPage(m_importPage);
 }
 
-void KexiCSVImportDialog::slotCommandLinkClicked()
-{
-    if (m_tableNameWidget) {
-        m_newTable = (sender() == m_newTableButton ? true : false);
-        m_tableNameWidget->setCurrentIndex(sender() == m_newTableButton ? 0 : 1);
-        next();
-    }
-}
-
 void KexiCSVImportDialog::initLater()
 {
     if (!openData())
@@ -1262,13 +1248,12 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
             }
             break;
         case S_MAYBE_NORMAL_FIELD :
-            if (x == m_textquote) {
+        case S_NORMAL_FIELD :
+            if (state == S_MAYBE_NORMAL_FIELD && x == m_textquote) {
                 field.clear();
                 state = S_QUOTED_FIELD;
                 break;
             }
-
-        case S_NORMAL_FIELD :
             if (x == delimiter || x == '\n' || x == '\r' || (x == commentSymbol && m_parseComments)) {
                 setText(row - m_startline, column, field, inGUI);
                 field.clear();
@@ -1290,7 +1275,8 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
             } else {
                 field += x;
             }
-        }
+            break;
+        } // switch
         if (x != delimiter)
             lastCharDelimiter = false;
 
@@ -1336,7 +1322,7 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
         if (nextRow) {
             nextRow = false;
             //additional speedup: stop processing now if too many bytes were loaded for preview
-            qDebug() << offset;
+            //qDebug() << offset;
             if (inGUI && offset >= m_maximumBytesForPreview && row >= 2) {
                 m_stoppedAt_MAX_BYTES_TO_PREVIEW = true;
                 return true;
@@ -1650,8 +1636,9 @@ void KexiCSVImportDialog::setText(int row, int col, const QString& text, bool in
             m_table->setRowCount(1);
             QString colName(text.simplified());
             if (!colName.isEmpty()) {
-                if (colName.left(1) >= "0" && colName.left(1) <= "9")
+                if (colName.at(0) >= QLatin1Char('0') && colName.at(0) <= QLatin1Char('9')) {
                     colName.prepend(xi18n("Column") + " ");
+                }
                 m_table->setData(m_table->index(0, col - 1), colName);
             }
             return;
@@ -1842,7 +1829,7 @@ void KexiCSVImportDialog::import()
         return;
     }
 
-    if (m_newTable) {
+    if (m_newTableOption->isChecked()) {
         m_destinationTableSchema = new KDbTableSchema(m_partItemForSavedTable->name());
         m_destinationTableSchema->setCaption(m_partItemForSavedTable->caption());
         m_destinationTableSchema->setDescription(m_partItemForSavedTable->description());
@@ -1994,7 +1981,10 @@ void KexiCSVImportDialog::import()
     KDbTransactionGuard tg(transaction);
 
     //-create physical table
-    if (m_newTable && !m_conn->createTable(m_destinationTableSchema, false /*allowOverwrite*/)) {
+    if (m_newTableOption->isChecked() && !m_conn->createTable(m_destinationTableSchema,
+        KDbConnection::CreateTableOptions(KDbConnection::CreateTableOption::Default)
+            & ~KDbConnection::CreateTableOptions(KDbConnection::CreateTableOption::DropDestination)))
+    {
         msg.showErrorMessage(m_conn->result());
         raiseErrorInAccept(project, m_partItemForSavedTable);
         return;
@@ -2055,7 +2045,7 @@ void KexiCSVImportDialog::import()
     }
 
     //-now we can store the item
-    if (m_newTable) {
+    if (m_newTableOption->isChecked()) {
         m_partItemForSavedTable->setIdentifier(m_destinationTableSchema->id());
         project->addStoredItem(part->info(), m_partItemForSavedTable);
     }
@@ -2186,3 +2176,5 @@ QPushButton* KexiCSVImportDialog::configureButton() const
     // Help button is used as Configure
     return button(QDialogButtonBox::Help);
 }
+
+#include "kexicsvimportdialog.moc"
