@@ -1,7 +1,7 @@
 /*
  * Kexi Report Plugin
  * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
-   Copyright (C) 2014 Jarosław Staniek <staniek@kde.org>
+ * Copyright (C) 2014-2017 Jarosław Staniek <staniek@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,13 +19,9 @@
 
 #include "kexireportview.h"
 #include <KReportView>
-#include "kexidbreportdata.h"
+#include "KexiDBReportDataSource.h"
 #ifndef KEXI_MOBILE
 #include <widget/utils/kexirecordnavigator.h>
- //! @todo KEXI3
-#if 0
-#include "keximigratereportdata.h"
-#endif
 #endif
 #include <core/KexiWindow.h>
 #include <core/KexiMainWindowIface.h>
@@ -94,12 +90,14 @@ KexiReportView::KexiReportView(QWidget *parent)
     exportMenu->setDelayed(false);
 #endif
 
+#ifdef KEXI_SHOW_UNFINISHED
 #ifdef KEXI_MOBILE
     viewActions << (a = new QAction(xi18n("Export:"), this));
     a->setEnabled(false); //!TODO this is a bit of a dirty way to add what looks like a label to the toolbar!
     // " ", not "", is said to be needed in maemo, the icon didn't display properly without it
     viewActions << (a = new QAction(koIcon("application-vnd.oasis.opendocument.text"), QLatin1String(" "), this));
 #else
+
     exportMenu->addAction(a = new QAction(koIcon("application-vnd.oasis.opendocument.text"),
                                           xi18nc("open dialog to export as text document", "Text Document..."), this));
 #endif
@@ -108,6 +106,7 @@ KexiReportView::KexiReportView(QWidget *parent)
     a->setWhatsThis(xi18n("Exports the report as a text document (in OpenDocument Text format)."));
     a->setEnabled(true);
     connect(a, SIGNAL(triggered()), this, SLOT(slotExportAsTextDocument()));
+#endif
 
 #ifdef KEXI_MOBILE
     viewActions << (a = new QAction(koIcon("application-pdf"), QLatin1String(" "), this));
@@ -121,6 +120,7 @@ KexiReportView::KexiReportView(QWidget *parent)
     a->setEnabled(true);
     connect(a, SIGNAL(triggered()), this, SLOT(slotExportAsPdf()));
 
+#ifdef KEXI_SHOW_UNFINISHED
 #ifdef KEXI_MOBILE
     viewActions << (a = new QAction(koIcon("application-vnd.oasis.opendocument.spreadsheet"), QLatin1String(" "), this));
 #else
@@ -133,6 +133,8 @@ KexiReportView::KexiReportView(QWidget *parent)
     a->setEnabled(true);
     connect(a, SIGNAL(triggered()), this, SLOT(slotExportAsSpreadsheet()));
 
+#endif
+
 #ifdef KEXI_MOBILE
     viewActions << (a = new QAction(koIcon("text-html"), QLatin1String(" "), this));
 #else
@@ -157,7 +159,6 @@ KexiReportView::KexiReportView(QWidget *parent)
 
 KexiReportView::~KexiReportView()
 {
-    qDebug();
     delete m_preRenderer;
 }
 
@@ -172,10 +173,14 @@ void KexiReportView::slotPrintReport()
     if (dialog.exec() == QDialog::Accepted) {
         KReportRendererContext cxt;
         QPainter painter;
-        cxt.printer = &printer;
-        cxt.painter = &painter;
+        cxt.setPrinter(&printer);
+        cxt.setPainter(&painter);
 
-        renderer->render(cxt, m_preRenderer->document());
+        if (!renderer->render(cxt, m_preRenderer->document())) {
+            KMessageBox::error(this,
+                               xi18n("Printing the report failed."),
+                               xi18n("Print Failed"));
+        }
     }
 }
 
@@ -185,30 +190,30 @@ void KexiReportView::slotExportAsPdf()
     if (renderer) {
         KReportRendererContext cxt;
 
-        cxt.destinationUrl = getExportUrl(QLatin1String("application/pdf"),
+        cxt.setUrl(getExportUrl(QLatin1String("application/pdf"),
                                           xi18n("Export Report as PDF"),
                                           "kfiledialog:///LastVisitedPDFExportPath/",
-                                          "pdf");
-        if (!cxt.destinationUrl.isValid()) {
+                                          "pdf"));
+        if (!cxt.url().isValid()) {
             return;
         }
 
         QPrinter printer;
         QPainter painter;
 
-        printer.setOutputFileName(cxt.destinationUrl.path());
+        printer.setOutputFileName(cxt.url().path());
         printer.setOutputFormat(QPrinter::PdfFormat);
         printer.setColorMode(QPrinter::Color);
 
         painter.begin(&printer);
-        cxt.printer = &printer;
-        cxt.painter = &painter;
+        cxt.setPrinter(&printer);
+        cxt.setPainter(&painter);
         if (!renderer->render(cxt, m_preRenderer->document())) {
             KMessageBox::error(this,
-                               xi18n("Exporting the report as PDF to %1 failed.", cxt.destinationUrl.toDisplayString()),
+                               xi18n("Exporting the report as PDF to %1 failed.", cxt.url().toDisplayString()),
                                xi18n("Export Failed"));
         } else {
-            openExportedDocument(cxt.destinationUrl);
+            openExportedDocument(cxt.url());
         }
    }
 }
@@ -218,6 +223,7 @@ QUrl KexiReportView::getExportUrl(const QString &mimetype, const QString &captio
 {
     QString defaultSavePath;
     QString recentDirClass;
+    //TODO use utils
     defaultSavePath = KFileWidget::getStartUrl(QUrl(lastExportPath), recentDirClass).toLocalFile()
         + '/' + window()->partItem()->captionOrName() + '.' + extension;
 
@@ -243,25 +249,27 @@ void KexiReportView::openExportedDocument(const QUrl &destination)
     }
 }
 
+#ifdef KEXI_SHOW_UNFINISHED
+
 void KexiReportView::slotExportAsSpreadsheet()
 {
     QScopedPointer<KReportRendererBase> renderer(m_factory.createInstance("ods"));
     if (renderer) {
         KReportRendererContext cxt;
-        cxt.destinationUrl = getExportUrl(QLatin1String("application/vnd.oasis.opendocument.spreadsheet"),
+        cxt.setUrl(getExportUrl(QLatin1String("application/vnd.oasis.opendocument.spreadsheet"),
                                           xi18n("Export Report as Spreadsheet"),
                                           "kfiledialog:///LastVisitedODSExportPath/",
-                                          "ods");
-        if (!cxt.destinationUrl.isValid()) {
+                                          "ods"));
+        if (!cxt.url().isValid()) {
             return;
         }
 
         if (!renderer->render(cxt, m_preRenderer->document())) {
             KMessageBox::error(this,
-                               xi18n("Failed to export the report as spreadsheet to %1.", cxt.destinationUrl.toDisplayString()),
+                               xi18n("Failed to export the report as spreadsheet to %1.", cxt.url().toDisplayString()),
                                xi18n("Export Failed"));
         } else {
-            openExportedDocument(cxt.destinationUrl);
+            openExportedDocument(cxt.url());
         }
     }
 }
@@ -273,33 +281,34 @@ void KexiReportView::slotExportAsTextDocument()
     //!       The same for other createInstance() calls.
     if (renderer) {
         KReportRendererContext cxt;
-        cxt.destinationUrl = getExportUrl(QLatin1String("application/vnd.oasis.opendocument.text"),
+        cxt.setUrl(getExportUrl(QLatin1String("application/vnd.oasis.opendocument.text"),
                                           xi18n("Export Report as Text Document"),
                                           "kfiledialog:///LastVisitedODTExportPath/",
-                                          "odt");
-        if (!cxt.destinationUrl.isValid()) {
+                                          "odt"));
+        if (!cxt.url().isValid()) {
             return;
         }
 
         if (!renderer->render(cxt, m_preRenderer->document())) {
             KMessageBox::error(this,
-                               xi18n("Exporting the report as text document to %1 failed.", cxt.destinationUrl.toDisplayString()),
+                               xi18n("Exporting the report as text document to %1 failed.", cxt.url().toDisplayString()),
                                xi18n("Export Failed"));
         } else {
-            openExportedDocument(cxt.destinationUrl);
+            openExportedDocument(cxt.url());
         }
     }
 }
+#endif
 
 void KexiReportView::slotExportAsWebPage()
 {
     const QString dialogTitle = xi18n("Export Report as Web Page");
     KReportRendererContext cxt;
-    cxt.destinationUrl = getExportUrl(QLatin1String("text/html"),
+    cxt.setUrl(getExportUrl(QLatin1String("text/html"),
                                       dialogTitle,
                                       "kfiledialog:///LastVisitedHTMLExportPath/",
-                                      "html");
-    if (!cxt.destinationUrl.isValid()) {
+                                      "html"));
+    if (!cxt.url().isValid()) {
         return;
     }
 
@@ -322,10 +331,10 @@ void KexiReportView::slotExportAsWebPage()
 
     if (!renderer->render(cxt, m_preRenderer->document())) {
         KMessageBox::error(this,
-                           xi18n("Exporting the report as web page to %1 failed.", cxt.destinationUrl.toDisplayString()),
+                           xi18n("Exporting the report as web page to %1 failed.", cxt.url().toDisplayString()),
                            xi18n("Export Failed"));
     } else {
-        openExportedDocument(cxt.destinationUrl);
+        openExportedDocument(cxt.url());
     }
 }
 
@@ -344,17 +353,17 @@ tristate KexiReportView::afterSwitchFrom(Kexi::ViewMode mode)
     if (tempData()->reportSchemaChangedInPreviousView) {
         tempData()->reportSchemaChangedInPreviousView = false;
 
-        qDebug() << "Schema changed";
         delete m_preRenderer;
 
         //qDebug() << tempData()->reportDefinition.tagName();
         m_preRenderer = new KReportPreRenderer(tempData()->reportDefinition);
         if (m_preRenderer->isValid()) {
-            KReportData *reportData = 0;
+            KReportDataSource *reportData = 0;
             if (!tempData()->connectionDefinition.isNull())  {
-                reportData = createSourceData(tempData()->connectionDefinition);
+                reportData = createDataSource(tempData()->connectionDefinition);
             }
-            m_preRenderer->setSourceData(reportData);
+            m_preRenderer->setDataSource(reportData);
+            m_preRenderer->setScriptSource(qobject_cast<KexiReportPart*>(part()));
 
             m_preRenderer->setName(window()->partItem()->name());
 
@@ -366,17 +375,18 @@ tristate KexiReportView::afterSwitchFrom(Kexi::ViewMode mode)
             //If using a kexidb source, add a functions scripting object
             if (tempData()->connectionDefinition.attribute("type") == "internal") {
                 m_functions = new KRScriptFunctions(reportData, KexiMainWindowIface::global()->project()->dbConnection());
-            
+
                 m_preRenderer->registerScriptObject(m_functions, "field");
                 connect(m_preRenderer, SIGNAL(groupChanged(QMap<QString, QVariant>)),
                         m_functions, SLOT(setGroupData(QMap<QString, QVariant>)));
             }
-            
+            connect(m_preRenderer, SIGNAL(finishedAllASyncItems()), this, SLOT(finishedAllASyncItems()));
+
             if (!m_preRenderer->generateDocument()) {
                 qWarning() << "Could not generate report document";
                 return false;
             }
-            
+
             m_reportView->setDocument(m_preRenderer->document());
 #ifndef KEXI_MOBILE
             m_pageSelector->setRecordCount(m_reportView->pageCount());
@@ -389,27 +399,17 @@ tristate KexiReportView::afterSwitchFrom(Kexi::ViewMode mode)
     return true;
 }
 
-KReportData* KexiReportView::createSourceData(QDomElement e)
+KReportDataSource* KexiReportView::createDataSource(const QDomElement &e)
 {
-    KReportData *kodata = 0;
-
     if (e.attribute("type") == "internal" && !e.attribute("source").isEmpty()) {
-        kodata = new KexiDBReportData(e.attribute("source"), KexiMainWindowIface::global()->project()->dbConnection());
+        return new KexiDBReportDataSource(e.attribute("source"), e.attribute("class"), tempData());
     }
-#ifndef KEXI_MOBILE
-//! @todo KEXI3
-#if 0
-    if (e.attribute("type") ==  "external") {
-        kodata = new KexiMigrateReportData(e.attribute("source"));
-    }
-#endif
-#endif
-    return kodata;
+    return nullptr;
 }
 
-KexiReportPart::TempData* KexiReportView::tempData() const
+KexiReportPartTempData* KexiReportView::tempData() const
 {
-    return static_cast<KexiReportPart::TempData*>(window()->data());
+    return static_cast<KexiReportPartTempData*>(window()->data());
 }
 
 void KexiReportView::addNewRecordRequested()
@@ -419,41 +419,45 @@ void KexiReportView::addNewRecordRequested()
 
 void KexiReportView::moveToFirstRecordRequested()
 {
-
     m_reportView->moveToFirstPage();
-    #ifndef KEXI_MOBILE
+#ifndef KEXI_MOBILE
     m_pageSelector->setCurrentRecordNumber(m_reportView->currentPage());
-    #endif
-
+#endif
 }
 
 void KexiReportView::moveToLastRecordRequested()
 {
     m_reportView->moveToLastPage();
-    #ifndef KEXI_MOBILE
+#ifndef KEXI_MOBILE
     m_pageSelector->setCurrentRecordNumber(m_reportView->currentPage());
-    #endif
+#endif
 }
 
 void KexiReportView::moveToNextRecordRequested()
 {
     m_reportView->moveToNextPage();
-    #ifndef KEXI_MOBILE
+#ifndef KEXI_MOBILE
     m_pageSelector->setCurrentRecordNumber(m_reportView->currentPage());
-    #endif
+#endif
 }
 
 void KexiReportView::moveToPreviousRecordRequested()
 {
     m_reportView->moveToPreviousPage();
-    #ifndef KEXI_MOBILE
+#ifndef KEXI_MOBILE
     m_pageSelector->setCurrentRecordNumber(m_reportView->currentPage());
-    #endif
+#endif
 }
 
 void KexiReportView::moveToRecordRequested(int r)
 {
-    Q_UNUSED(r);
+#ifdef KEXI_MOBILE
+    m_reportView->moveToPage(r + 1);
+#else
+    // set in the navigator widget first, this will fix up the value it it's too small or large
+    m_pageSelector->setCurrentRecordNumber(r + 1);
+    m_reportView->moveToPage(m_pageSelector->currentRecordNumber());
+#endif
 }
 
 int KexiReportView::currentRecord() const
@@ -465,3 +469,8 @@ int KexiReportView::recordCount() const
 {
     return m_reportView->pageCount();
 }
+
+void KexiReportView::finishedAllASyncItems()
+{
+    m_reportView->refreshCurrentPage();
+}
