@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2012 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2017 Jarosław Staniek <staniek@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,6 +31,7 @@
 #include <KexiWindow.h>
 #include <kexi_global.h>
 
+#include <KPropertyListData>
 #include <KPropertySet>
 
 #include <KDbConnection>
@@ -105,8 +106,6 @@ KexiTableDesignerView::KexiTableDesignerView(QWidget *parent)
         , d(new KexiTableDesignerViewPrivate(this))
 {
     setObjectName("KexiTableDesignerView");
-    //needed for custom "identifier" property editor widget
-    KexiCustomPropertyFactory::init();
 
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
     d->view = dynamic_cast<KexiTableScrollArea*>(mainWidget());
@@ -174,8 +173,8 @@ KexiTableDesignerView::KexiTableDesignerView(QWidget *parent)
     viewActions << (d->action_toggle_pkey = new KToggleAction(KexiIcon("database-key"), xi18n("Primary Key"), this));
     a = d->action_toggle_pkey;
     a->setObjectName("tablepart_toggle_pkey");
-    a->setToolTip(xi18n("Sets or removes primary key"));
-    a->setWhatsThis(xi18n("Sets or removes primary key for currently selected field."));
+    a->setToolTip(xi18n("Sets or deletes primary key"));
+    a->setWhatsThis(xi18n("Sets or deletes primary key for currently selected field."));
     connect(a, SIGNAL(triggered()), this, SLOT(slotTogglePrimaryKey()));
     setViewActions(viewActions);
 
@@ -218,12 +217,12 @@ void KexiTableDesignerView::initData()
     int tableFieldCount = 0;
     d->primaryKeyExists = false;
 
-    if (tempData()->table) {
-        tableFieldCount = tempData()->table->fieldCount();
+    if (tempData()->table()) {
+        tableFieldCount = tempData()->table()->fieldCount();
 
         //recreate table data records
         for (int i = 0; i < tableFieldCount; i++) {
-            KDbField *field = tempData()->table->field(i);
+            KDbField *field = tempData()->table()->field(i);
             KDbRecordData *data = d->data->createItem();
             if (field->isPrimaryKey()) {
                 (*data)[COLUMN_ID_ICON] = KexiIconName("database-key");
@@ -232,7 +231,7 @@ void KexiTableDesignerView::initData()
                 KDbLookupFieldSchema *lookupFieldSchema
                     = field->table() ? field->table()->lookupFieldSchema(*field) : 0;
                 if (lookupFieldSchema
-                    && lookupFieldSchema->recordSource().type() != KDbLookupFieldSchema::RecordSource::NoType
+                    && lookupFieldSchema->recordSource().type() != KDbLookupFieldSchemaRecordSource::Type::None
                     && !lookupFieldSchema->recordSource().name().isEmpty())
                 {
                     (*data)[COLUMN_ID_ICON] = KexiIconName("combobox");
@@ -255,9 +254,9 @@ void KexiTableDesignerView::initData()
     d->view->setData(d->data);
 
     //now recreate property sets
-    if (tempData()->table) {
+    if (tempData()->table()) {
         for (int i = 0; i < tableFieldCount; i++) {
-            KDbField *field = tempData()->table->field(i);
+            KDbField *field = tempData()->table()->field(i);
             createPropertySet(i, *field);
         }
     }
@@ -278,9 +277,7 @@ void KexiTableDesignerView::initData()
 }
 
 //! Gets subtype strings and names for type \a fieldType
-void
-KexiTableDesignerView::getSubTypeListData(KDbField::TypeGroup fieldTypeGroup,
-        QStringList& stringsList, QStringList& namesList)
+static KPropertyListData *getSubTypeListData(KDbField::TypeGroup fieldTypeGroup)
 {
     /* disabled - "mime" is moved from subType to "objectType" custom property
       if (fieldTypeGroup==KDbField::BLOBGroup) {
@@ -290,11 +287,12 @@ KexiTableDesignerView::getSubTypeListData(KDbField::TypeGroup fieldTypeGroup,
         namesList << xi18n("Image object type", "Image");
       }
       else {*/
-    stringsList = KDb::fieldTypeStringsForGroup(fieldTypeGroup);
-    namesList = KDb::fieldTypeNamesForGroup(fieldTypeGroup);
-// }
-    qDebug() << "subType strings: " <<
-        stringsList.join("|") << "\nnames: " << namesList.join("|");
+    KPropertyListData *listData = new KPropertyListData(
+        KDb::fieldTypeStringsForGroup(fieldTypeGroup), KDb::fieldTypeNamesForGroup(fieldTypeGroup));
+    // }
+    qDebug() << "subType strings: " << listData->keysAsStringList().join("|")
+             << "\nnames: " << listData->namesAsStringList().join("|");
+    return listData;
 }
 
 KPropertySet *
@@ -331,8 +329,7 @@ KexiTableDesignerView::createPropertySet(int record, const KDbField& field, bool
 #endif
 
     //subtype
-    QStringList typeStringList, typeNameList;
-    getSubTypeListData(field.typeGroup(), typeStringList, typeNameList);
+    KPropertyListData *listData = getSubTypeListData(field.typeGroup());
     /* disabled - "mime" is moved from subType to "objectType" custom property
       QString subTypeValue;
       if (field.typeGroup()==KDbField::BLOBGroup) {
@@ -341,21 +338,20 @@ KexiTableDesignerView::createPropertySet(int record, const KDbField& field, bool
         subTypeValue = slist.first();
       }
       else {*/
-    QString subTypeValue = field.typeString();
+    QVariant subTypeValue = field.typeString();
     //}
-    set->addProperty(prop = new KProperty("subType",
-            typeStringList, typeNameList, subTypeValue, xi18n("Subtype")));
+    set->addProperty(prop = new KProperty("subType", listData, subTypeValue, xi18n("Subtype")));
 
     // objectType
-    QStringList objectTypeStringList, objectTypeNameList;
 //! @todo this should be retrieved from KDbField when BLOB supports many different mimetypes
-    objectTypeStringList << "image";
-    objectTypeNameList << xi18nc("Image object type", "Image");
-    QString objectTypeValue(field.customProperty("objectType").toString());
-    if (objectTypeValue.isEmpty())
+
+    listData
+        = new KPropertyListData({ "image" }, QVariantList{ xi18nc("Image object type", "Image") });
+    QVariant objectTypeValue(field.customProperty("objectType"));
+    if (objectTypeValue.toString().isEmpty())
         objectTypeValue = DEFAULT_OBJECT_TYPE_VALUE;
     set->addProperty(prop = new KProperty("objectType",
-            objectTypeStringList, objectTypeNameList, objectTypeValue,
+            listData, objectTypeValue,
             xi18n("Subtype")/*! @todo other i18n string?*/));
 
     set->addProperty(prop = new KProperty("caption", QVariant(field.caption()),
@@ -400,7 +396,7 @@ KexiTableDesignerView::createPropertySet(int record, const KDbField& field, bool
 
     set->addProperty(prop = new KProperty("primaryKey", QVariant(field.isPrimaryKey()),
                                                      xi18n("Primary Key")));
-    prop->setIcon(KexiIconName("database-key"));
+    prop->setIconName(KexiIconName("database-key"));
 
     set->addProperty(prop = new KProperty("unique", QVariant(field.isUniqueKey()),
                                                      xi18n("Unique")));
@@ -413,15 +409,15 @@ KexiTableDesignerView::createPropertySet(int record, const KDbField& field, bool
 
     set->addProperty(prop = new KProperty("autoIncrement", QVariant(field.isAutoIncrement()),
                                                      xi18n("Autonumber")));
-    prop->setIcon(koIconName("autonumber"));
+    prop->setIconName(koIconName("autonumber"));
 
     set->addProperty(prop = new KProperty("indexed", QVariant(field.isIndexed()),
                                                      xi18n("Indexed")));
 
     //- properties related to lookup columns (used and set by the "lookup column"
     //  tab in the property pane)
-    KDbLookupFieldSchema *lookupFieldSchema
-        = field.table() ? field.table()->lookupFieldSchema(field) : 0;
+    const KDbLookupFieldSchema *lookupFieldSchema
+        = field.table() ? field.table()->lookupFieldSchema(field) : nullptr;
     set->addProperty(prop = new KProperty("rowSource",
         lookupFieldSchema ? lookupFieldSchema->recordSource().name() : QString(), xi18n("Record Source")));
     prop->setVisible(false);
@@ -580,7 +576,7 @@ tristate KexiTableDesignerView::beforeSwitchTo(Kexi::ViewMode mode, bool *dontSt
             KGuiItem discardItem(KStandardGuiItem::discard());
             discardItem.setToolTip(QString());
             if (isPhysicalAlteringNeeded) {
-                saveItem.setText(xi18nc("@action:button", "Save Design and Remove Table Data"));
+                saveItem.setText(xi18nc("@action:button", "Save Design and Delete Table Data"));
                 discardItem.setText(xi18nc("@action:button", "Discard Design"));
             }
             const KMessageBox::ButtonCode r = KMessageBox::warningYesNoCancel(this,
@@ -705,15 +701,14 @@ void KexiTableDesignerView::slotBeforeCellChanged(
         if (fieldType == KDbField::InvalidType)
             fieldType = KDbField::Text;
 
-        //-get subtypes for this type: keys (slist) and names (nlist)
-        QStringList slist, nlist;
-        getSubTypeListData(fieldTypeGroup, slist, nlist);
+        //-get subtypes for this type:
+        KPropertyListData *listData = getSubTypeListData(fieldTypeGroup);
 
-        QString subTypeValue;
+        QVariant subTypeValue;
         /* disabled - "mime" is moved from subType to "objectType" custom property
             if (fieldType==KDbField::BLOB) {
               // special case: BLOB type uses "mime-based" subtypes
-              subTypeValue = slist.first();
+              subTypeValue = listData->keys().first();
             }
             else {*/
         subTypeValue = KDbField::typeString(fieldType);
@@ -731,11 +726,10 @@ void KexiTableDesignerView::slotBeforeCellChanged(
         //update subtype list and value
         const bool forcePropertySetReload = KDbField::typeGroup(
             KDbField::typeForString(subTypeProperty->value().toString())) != fieldTypeGroup;   //<-- ?????
-        const bool useListData = slist.count() > 1;
+        const bool useListData = listData->keys().count() > 1;
 
         if (!useListData) {
-            slist.clear(); //empty list will be passed
-            nlist.clear();
+            *listData = KPropertyListData(); //empty list will be passed
         }
         d->setPropertyValueIfNeeded(set, "type", (int)fieldType, changeDataTypeCommand,
                                     false /*!forceAddCommand*/, true /*rememberOldValue*/);
@@ -761,7 +755,7 @@ void KexiTableDesignerView::slotBeforeCellChanged(
         }
         d->setPropertyValueIfNeeded(set, "subType", subTypeValue,
                                     changeDataTypeCommand, false, false /*!rememberOldValue*/,
-                                    &slist, &nlist);
+                                    listData);
 
         if (d->updatePropertiesVisibility(fieldType, set, changeDataTypeCommand)
                 || forcePropertySetReload) {
@@ -871,9 +865,9 @@ void KexiTableDesignerView::slotPropertyChanged(KPropertySet& set, KProperty& pr
     qDebug() << pname << " = " << property.value()
         << " (oldvalue = " << property.oldValue() << ")";
 
-    // true is PK should be altered
+    // true if PK should be altered
     bool changePrimaryKey = false;
-    // true is PK should be set to true, otherwise unset
+    // true if PK should be set to true, otherwise unset
     bool setPrimaryKey = false;
 
     if (pname == "primaryKey" && d->slotPropertyChanged_primaryKey_enabled) {
@@ -899,7 +893,7 @@ void KexiTableDesignerView::slotPropertyChanged(KPropertySet& set, KProperty& pr
             QString msg =
               xi18n("<para>Setting autonumber requires primary key to be set for current field.</para>");
             if (d->primaryKeyExists)
-                msg += xi18n("<para>Previous primary key will be removed.</para>");
+                msg += xi18n("<para>Previous primary key will be deleted.</para>");
             msg += xi18n("<para>Do you want to create primary key for current field? "
                         "Click <interface>Cancel</interface> to cancel setting autonumber.</para>");
 
@@ -917,7 +911,7 @@ void KexiTableDesignerView::slotPropertyChanged(KPropertySet& set, KProperty& pr
                 d->setPropertyValueIfNeeded(set, "autoIncrement", QVariant(true), setAutonumberCommand);
             } else {
                 setAutonumberCommand = new Command(
-                    kundo2_i18n("Remove autonumber from field <resource>%1</resource>", set["name"].value().toString()),
+                    kundo2_i18n("Delete autonumber from field <resource>%1</resource>", set["name"].value().toString()),
                     0, this);
                 d->setPropertyValueIfNeeded(set, "autoIncrement", QVariant(false), setAutonumberCommand,
                                             true /*forceAddCommand*/, false/*rememberOldValue*/);
@@ -1263,8 +1257,10 @@ tristate KexiTableDesignerView::buildSchema(KDbTableSchema &schema, bool beSilen
         {
             //add lookup column
             KDbLookupFieldSchema *lookupFieldSchema = new KDbLookupFieldSchema();
-            lookupFieldSchema->recordSource().setTypeByName((*s)["rowSourceType"].value().toString());
-            lookupFieldSchema->recordSource().setName((*s)["rowSource"].value().toString());
+            KDbLookupFieldSchemaRecordSource recordSource;
+            recordSource.setTypeByName((*s)["rowSourceType"].value().toString());
+            recordSource.setName((*s)["rowSource"].value().toString());
+            lookupFieldSchema->setRecordSource(recordSource);
             lookupFieldSchema->setBoundColumn((*s)["boundColumn"].value().toInt());
 //! @todo this is backward-compatible code for "single visible column" implementation
 //!       for multiple columns, only the first is displayed, so there is a data loss is GUI is used
@@ -1324,25 +1320,29 @@ KDbObject* KexiTableDesignerView::storeNewData(const KDbObject& object,
                                                         bool *cancel)
 {
     Q_ASSERT(cancel);
-    if (tempData()->table || window()->schemaObject()) //must not be
+    if (tempData()->table() || window()->schemaObject()) //must not be
         return 0;
 
     //create table schema definition
-    tempData()->table = new KDbTableSchema(object.name());
-    tempData()->table->setName(object.name());
-    tempData()->table->setCaption(object.caption());
-    tempData()->table->setDescription(object.description());
+    tempData()->setTable(new KDbTableSchema(object.name()));
+    tempData()->table()->setName(object.name());
+    tempData()->table()->setCaption(object.caption());
+    tempData()->table()->setDescription(object.description());
 
-    tristate res = buildSchema(*tempData()->table);
+    tristate res = buildSchema(*tempData()->table());
     *cancel = ~res;
 
     //FINALLY: create table:
     if (res == true) {
         //! @todo
         KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-        res = conn->createTable(tempData()->table, options & KexiView::OverwriteExistingData);
+        KDbConnection::CreateTableOptions createOptions(KDbConnection::CreateTableOption::Default);
+        if (options & KexiView::OverwriteExistingData) {
+            createOptions |= KDbConnection::CreateTableOption::DropDestination;
+        }
+        res = conn->createTable(tempData()->table(), createOptions);
         if (res == true) {
-            res = KexiMainWindowIface::global()->project()->removeUserDataBlock(tempData()->table->id());
+            res = KexiMainWindowIface::global()->project()->removeUserDataBlock(tempData()->table()->id());
         }
         else {
             window()->setStatus(conn, "");
@@ -1354,10 +1354,11 @@ KDbObject* KexiTableDesignerView::storeNewData(const KDbObject& object,
         tempData()->tableSchemaChangedInPreviousView = true;
         d->history->clear();
     } else {
-        delete tempData()->table;
-        tempData()->table = 0;
+        KDbTableSchema *tableToDelete = tempData()->table();
+        tempData()->setTable(nullptr);
+        delete tableToDelete;
     }
-    return tempData()->table;
+    return tempData()->table();
 }
 
 KDbObject* KexiTableDesignerView::copyData(const KDbObject& object,
@@ -1368,16 +1369,16 @@ KDbObject* KexiTableDesignerView::copyData(const KDbObject& object,
     Q_UNUSED(options);
     Q_UNUSED(cancel);
 
-    if (!tempData()->table) {
+    if (!tempData()->table()) {
         qWarning() << "Cannot copy data without source table (tempData()->table)";
         return 0;
     }
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-    KDbTableSchema *copiedTable = conn->copyTable(*tempData()->table, object);
+    KDbTableSchema *copiedTable = conn->copyTable(*tempData()->table(), object);
     if (!copiedTable) {
         return 0;
     }
-    if (!KexiMainWindowIface::global()->project()->copyUserDataBlock(tempData()->table->id(),
+    if (!KexiMainWindowIface::global()->project()->copyUserDataBlock(tempData()->table()->id(),
                                                                      copiedTable->id()))
     {
         conn->dropTable(copiedTable);
@@ -1389,7 +1390,7 @@ KDbObject* KexiTableDesignerView::copyData(const KDbObject& object,
 
 tristate KexiTableDesignerView::storeData(bool dontAsk)
 {
-    if (!tempData()->table || !window()->schemaObject()) {
+    if (!tempData()->table() || !window()->schemaObject()) {
         d->recentResultOfStoreData = false;
         return false;
     }
@@ -1411,7 +1412,7 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
             //only compute requirements
             KDbAlterTableHandler::ExecutionArguments args;
             args.onlyComputeRequirements = true;
-            (void)alterTableHandler->execute(tempData()->table->name(), &args);
+            (void)alterTableHandler->execute(tempData()->table()->name(), &args);
             res = args.result;
             if (   res == true
                 && 0 == (args.requirements & (0xffff ^ KDbAlterTableHandler::SchemaAlteringRequired)))
@@ -1423,11 +1424,11 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
 
     if (res == true) {
         res = KexiTablePart::askForClosingObjectsUsingTableSchema(
-                  this, conn, tempData()->table,
-                  xi18nc("@info",
-                         "You are about to change the design of table <resource>%1</resource> "
-                         "but following objects using this table are opened:",
-                         tempData()->table->name()));
+            window(), conn, tempData()->table(),
+            kxi18nc("@info",
+                    "<para>You are about to change the design of table <resource>%1</resource> "
+                    "but following objects using this table are open:</para>")
+                .subs(tempData()->table()->name()));
     }
 
     if (res == true) {
@@ -1440,8 +1441,13 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
                 bool emptyTable;
                 const QString msg = d->messageForSavingChanges(&emptyTable).toString();
                 if (!emptyTable) {
-                    if (KMessageBox::No == KMessageBox::questionYesNo(this, msg))
+                    if (KMessageBox::No == KMessageBox::questionYesNo(
+                                               this, msg, QString(), KStandardGuiItem::save(),
+                                               KStandardGuiItem::dontSave(), QString(),
+                                               KMessageBox::Notify | KMessageBox::Dangerous))
+                    {
                         res = cancelled;
+                    }
                 }
             }
             d->dontAskOnStoreData = false; //one-time use
@@ -1453,16 +1459,21 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
             newTable = new KDbTableSchema();
             // copy the object data
             static_cast<KDbObject&>(*newTable)
-                = static_cast<KDbObject&>(*tempData()->table);
+                = static_cast<KDbObject&>(*tempData()->table());
             res = buildSchema(*newTable);
             qDebug() << "BUILD SCHEMA:" << *newTable;
-
-            res = conn->alterTable(tempData()->table, newTable);
+            {
+                KDbTableSchema *oldTable = tempData()->table();
+                tempData()->setTable(nullptr); // needed, otherwise setTable() will access dangling
+                                               // pointer after conn->alterTable()
+                KexiUtils::BoolBlocker guard(&tempData()->closeWindowOnCloseListener, false);
+                res = conn->alterTable(oldTable, newTable);
+            }
             if (res != true)
                 window()->setStatus(conn, "");
         } else {
             KDbAlterTableHandler::ExecutionArguments args;
-            newTable = alterTableHandler->execute(tempData()->table->name(), &args);
+            newTable = alterTableHandler->execute(tempData()->table()->name(), &args);
             res = args.result;
             qDebug() << "ALTER TABLE EXECUTE: "
             << res.toString();
@@ -1474,7 +1485,7 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
     }
     if (res == true) {
         //change current schema
-        tempData()->table = newTable;
+        tempData()->setTable(newTable);
         tempData()->tableSchemaChangedInPreviousView = true;
         d->history->clear();
     } else {
@@ -1493,7 +1504,7 @@ tristate KexiTableDesignerView::simulateAlterTableExecution(QString *debugTarget
         //to avoid executing for multiple alter table views
         return false;
     }
-    if (!tempData()->table || !window()->schemaObject())
+    if (!tempData()->table() || !window()->schemaObject())
         return false;
     KDbConnection *conn = KexiMainWindowIface::global()->project()->dbConnection();
     KDbAlterTableHandler::ActionList actions;
@@ -1507,7 +1518,7 @@ tristate KexiTableDesignerView::simulateAlterTableExecution(QString *debugTarget
     } else {
         args.simulate = true;
     }
-    (void)alterTableHandler.execute(tempData()->table->name(), &args);
+    (void)alterTableHandler.execute(tempData()->table()->name(), &args);
     return args.result;
 # else
     Q_UNUSED(debugTarget);
@@ -1535,17 +1546,17 @@ tristate KexiTableDesignerView::executeRealAlterTable()
     return d->recentResultOfStoreData;
 }
 
-KexiTablePart::TempData* KexiTableDesignerView::tempData() const
+KexiTablePartTempData* KexiTableDesignerView::tempData() const
 {
-    return static_cast<KexiTablePart::TempData*>(window()->data());
+    return static_cast<KexiTablePartTempData*>(window()->data());
 }
 
 #ifdef KEXI_DEBUG_GUI
 void KexiTableDesignerView::debugCommand(const KUndo2Command* command, int nestingLevel)
 {
-    if (dynamic_cast<const Command*>(command)) {
-        KDb::alterTableActionDebugGUI(
-            dynamic_cast<const Command*>(command)->debugString(), nestingLevel);
+    const Command* kexiCommand = dynamic_cast<const Command*>(command);
+    if (kexiCommand) {
+        KDb::alterTableActionDebugGUI(kexiCommand->debugString(), nestingLevel);
     }
     else {
         KDb::alterTableActionDebugGUI(command->text().toString(), nestingLevel);
@@ -1626,7 +1637,7 @@ QString KexiTableDesignerView::debugStringForCurrentTableSchema(tristate& result
     KDbTableSchema tempTable;
     //copy object data
     static_cast<KDbObject&>(tempTable)
-        = static_cast<KDbObject&>(*tempData()->table);
+        = static_cast<KDbObject&>(*tempData()->table());
     result = buildSchema(tempTable, true /*beSilent*/);
     if (true != result) {
         return QString();
@@ -1748,7 +1759,7 @@ void KexiTableDesignerView::deleteRecord(int record, bool addCommand)
 
 void KexiTableDesignerView::changeFieldPropertyForRecord(int record,
         const QByteArray& propertyName, const QVariant& newValue,
-        KPropertyListData* const listData, bool addCommand)
+        const KPropertyListData* listData, bool addCommand)
 {
 #ifdef KEXI_DEBUG_GUI
     KDb::alterTableActionDebugGUI(QString("** changeFieldProperty: \"")
@@ -1763,10 +1774,11 @@ void KexiTableDesignerView::changeFieldPropertyForRecord(int record,
         return;
     KProperty &property = set->property(propertyName);
     if (listData) {
-        if (listData->keys.isEmpty())
-            property.setListData(0);
-        else
+        if (listData->keys().isEmpty()) {
+            property.setListData(nullptr);
+        } else {
             property.setListData(new KPropertyListData(*listData));
+        }
     }
     if (propertyName != "type") //delayed type update (we need to have subtype set properly)
         property.setValue(newValue);
@@ -1817,7 +1829,7 @@ void KexiTableDesignerView::changeFieldPropertyForRecord(int record,
 
 void KexiTableDesignerView::changeFieldProperty(int fieldUID,
         const QByteArray& propertyName, const QVariant& newValue,
-        KPropertyListData* const listData, bool addCommand)
+        const KPropertyListData* listData, bool addCommand)
 {
     //find a property by UID
     const int record = d->sets->findRecordForPropertyValue("uid", fieldUID);
@@ -1877,7 +1889,7 @@ bool KexiTableDesignerView::isPhysicalAlteringNeeded()
     //only compute requirements
     KDbAlterTableHandler::ExecutionArguments args;
     args.onlyComputeRequirements = true;
-    (void)alterTableHandler->execute(tempData()->table->name(), &args);
+    (void)alterTableHandler->execute(tempData()->table()->name(), &args);
     res = args.result;
     delete alterTableHandler;
     if (   res == true
