@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
    Copyright (C) 2002, 2003 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2004-2010 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2017 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,12 +24,15 @@
 #include <core/KexiMainWindowIface.h>
 #include <core/kexiproject.h>
 #include <core/kexipartinfo.h>
+#include <kexiutils/utils.h>
+#include <widget/properties/KexiCustomPropertyFactory.h>
 #include <widget/tableview/KexiDataTableView.h>
 #include <widget/tableview/KexiDataTableScrollArea.h>
 #include "kexitabledesignerview.h"
 #include "kexitabledesigner_dataview.h"
 #include "kexilookupcolumnpage.h"
 #include <KexiWindow.h>
+#include <kexiutils/utils.h>
 
 #include <KDbConnection>
 
@@ -41,7 +44,7 @@
 KEXI_PLUGIN_FACTORY(KexiTablePart, "kexi_tableplugin.json")
 
 //! @internal
-class KexiTablePart::Private
+class Q_DECL_HIDDEN KexiTablePart::Private
 {
 public:
     Private() {
@@ -63,6 +66,9 @@ KexiTablePart::KexiTablePart(QObject *parent, const QVariantList& l)
         l)
   , d(new Private)
 {
+    // needed for custom "identifier" property editor widget
+    KexiCustomPropertyFactory::init();
+
 //! @todo js: also add Kexi::TextViewMode when we'll have SQL ALTER TABLE EDITOR!!!
 }
 
@@ -81,7 +87,8 @@ void KexiTablePart::initInstanceActions()
 
 KexiWindowData* KexiTablePart::createWindowData(KexiWindow* window)
 {
-    return new KexiTablePartTempData(window);
+    KexiMainWindowIface *win = KexiMainWindowIface::global();
+    return new KexiTablePartTempData(window, win->project()->dbConnection());
 }
 
 KexiView* KexiTablePart::createView(QWidget *parent, KexiWindow* window,
@@ -95,16 +102,16 @@ KexiView* KexiTablePart::createView(QWidget *parent, KexiWindow* window,
 
     KexiTablePartTempData *temp
         = static_cast<KexiTablePartTempData*>(window->data());
-    if (!temp->table) {
-        temp->table = win->project()->dbConnection()->tableSchema(item->name());
-        qDebug() << "schema is " << temp->table;
+    if (!temp->table()) {
+        temp->setTable(win->project()->dbConnection()->tableSchema(item->name()));
+        qDebug() << "schema is " << temp->table();
     }
 
     if (viewMode == Kexi::DesignViewMode) {
         KexiTableDesignerView *t = new KexiTableDesignerView(parent);
         return t;
     } else if (viewMode == Kexi::DataViewMode) {
-        if (!temp->table) {
+        if (!temp->table()) {
             return 0; //!< @todo message
         }
         //we're not setting table schema here -it will be forced to set
@@ -125,10 +132,11 @@ tristate KexiTablePart::remove(KexiPart::Item *item)
     KDbTableSchema *sch = conn->tableSchema(item->identifier());
 
     if (sch) {
-        tristate res = KexiTablePart::askForClosingObjectsUsingTableSchema(
-            KexiMainWindowIface::global()->thisWidget(), conn, sch,
-            xi18n("You are about to remove table <resource>%1</resource> but following objects using this table are opened:",
-                 sch->name()));
+        const tristate res = KexiTablePart::askForClosingObjectsUsingTableSchema(
+            KexiMainWindowIface::global()->openedWindowFor(item->identifier()), conn, sch,
+            kxi18n("<para>You are about to delete table <resource>%1</resource> but it is used by "
+                   "following opened windows:</para>")
+                .subs(sch->name()));
         if (res != true) {
             return res;
         }
@@ -145,10 +153,11 @@ tristate KexiTablePart::rename(KexiPart::Item *item, const QString& newName)
     KDbTableSchema *schema = conn->tableSchema(item->identifier());
     if (!schema)
         return false;
-    tristate res = KexiTablePart::askForClosingObjectsUsingTableSchema(
-        KexiMainWindowIface::global()->thisWidget(), conn, schema,
-        xi18n("You are about to rename table <resource>%1</resource> but following objects using this table are opened:",
-             schema->name()));
+    const tristate res = KexiTablePart::askForClosingObjectsUsingTableSchema(
+        KexiMainWindowIface::global()->openedWindowFor(item->identifier()), conn, schema,
+        kxi18n("<para>You are about to rename table <resource>%1</resource> but it is used by "
+               "following opened windows:</para>")
+            .subs(schema->name()));
     if (res != true) {
         return res;
     }
@@ -160,44 +169,66 @@ KDbObject* KexiTablePart::loadSchemaObject(KexiWindow *window, const KDbObject&
 {
     Q_UNUSED(window);
     Q_UNUSED(viewMode);
-    if (ownedByWindow)
-        *ownedByWindow = false;
+    Q_ASSERT(ownedByWindow);
+    *ownedByWindow = false;
     return KexiMainWindowIface::global()->project()->dbConnection()->tableSchema(object.name());
 }
 
-//static
-tristate KexiTablePart::askForClosingObjectsUsingTableSchema(
-    QWidget *parent, KDbConnection *conn,
-    KDbTableSchema *table, const QString& msg)
+// static
+tristate KexiTablePart::askForClosingObjectsUsingTableSchema(KexiWindow *window,
+                                                             KDbConnection *conn,
+                                                             KDbTableSchema *table,
+                                                             const KLocalizedString &msg)
 {
     Q_ASSERT(conn);
     Q_ASSERT(table);
-    QSet<KDbConnection::TableSchemaChangeListenerInterface*>* listeners
-        = conn->tableSchemaChangeListeners(table);
-    if (!listeners || listeners->isEmpty())
+    if (!window) {
+        return true;
+    }
+    QList<KDbTableSchemaChangeListener*> listeners
+            = KDbTableSchemaChangeListener::listeners(conn, table);
+    KexiTablePartTempData *temp = static_cast<KexiTablePartTempData*>(window->data());
+    // Special case: listener that is equal to window->data() will be silently closed
+    // without asking for confirmation. It is not counted when looking for objects that
+    // are "blocking" changes of the table.
+    const bool tempListenerExists = listeners.removeAll(temp) > 0;
+    // Immediate success if there's no temp-data's listener to close nor other listeners to close
+    if (!tempListenerExists && listeners.isEmpty()) {
         return true;
-
-    QString openedObjectsStr = "<list>";
-    foreach(KDbConnection::TableSchemaChangeListenerInterface* iface, *listeners) {
-        openedObjectsStr += QString("<item>%1</item>").arg(iface->listenerInfoString);
     }
-    openedObjectsStr += "</list>";
-    int r = KMessageBox::questionYesNo(parent,
-                                       i18nc("@info", "<para>%1</para><para>%2</para>", msg, openedObjectsStr)
-                                       + "<para>"
-                                       + xi18n("Do you want to close all windows for these objects?")
-                                       + "</para>",
-                                       QString(), KGuiItem(xi18nc("@action:button Close All Windows", "Close Windows"), koIconName("window-close")), KStandardGuiItem::cancel());
-    tristate res;
-    if (r == KMessageBox::Yes) {
-        //try to close every window
-        res = conn->closeAllTableSchemaChangeListeners(table);
-        if (res != true) //do not expose closing errors twice; just cancel
-            res = cancelled;
-    } else
-        res = cancelled;
 
-    return res;
+    if (!listeners.isEmpty()) {
+        QString openedObjectsStr = "<p><ul>";
+        for(const KDbTableSchemaChangeListener* listener : listeners) {
+            openedObjectsStr += QString("<li>%1</li>").arg(listener->name());
+        }
+        openedObjectsStr += "</ul></p>";
+        QString message = "<html>"
+            + i18nc("@info/plain Sentence1 Sentence2 Sentence3", "%1%2%3",
+                    KexiUtils::localizedStringToHtmlSubstring(msg), openedObjectsStr,
+                    KexiUtils::localizedStringToHtmlSubstring(
+                        kxi18nc("@info", "<para>Do you want to close these windows and save the "
+                                         "design or cancel saving?</para>")))
+            + "</html>";
+        KGuiItem closeAndSaveItem(KStandardGuiItem::save());
+        closeAndSaveItem.setText(
+            xi18nc("@action:button Close all windows and save", "Close Windows and Save"));
+        closeAndSaveItem.setToolTip(xi18nc("@info:tooltip Close all windows and save design",
+                                           "Close all windows and save design"));
+        const int r = KMessageBox::questionYesNo(window, message, QString(), closeAndSaveItem,
+                                                 KStandardGuiItem::cancel(), QString(),
+                                                 KMessageBox::Notify | KMessageBox::Dangerous);
+        if (r != KMessageBox::Yes) {
+            return cancelled;
+        }
+    }
+    // try to close every window depending on the table (if present) and also the temp-data's
+    // listener (if present)
+    const tristate res = KDbTableSchemaChangeListener::closeListeners(conn, table, { temp });
+    if (res != true) { //do not expose closing errors twice; just cancel
+        return cancelled;
+    }
+    return true;
 }
 
 KLocalizedString KexiTablePart::i18nMessage(
@@ -212,7 +243,7 @@ KLocalizedString KexiTablePart::i18nMessage(
 
     if (window->currentViewMode() == Kexi::DesignViewMode && !window->neverSaved()
             && englishMessage == ":additional message before saving design")
-        return kxi18nc(I18NC_NOOP("@info", "<warning>Any data in this table will be removed upon design's saving!</warning>"));
+        return kxi18nc(I18NC_NOOP("@info", "<warning>Any data in this table will be deleted upon design's saving!</warning>"));
 
     return Part::i18nMessage(englishMessage, window);
 }
@@ -251,11 +282,80 @@ KexiLookupColumnPage* KexiTablePart::lookupColumnPage() const
 
 //----------------
 
-KexiTablePartTempData::KexiTablePartTempData(QObject* parent)
-        : KexiWindowData(parent)
-        , table(0)
-        , tableSchemaChangedInPreviousView(true /*to force reloading on startup*/)
+class Q_DECL_HIDDEN KexiTablePartTempData::Private
 {
+public:
+    Private()
+        : table(nullptr)
+    {
+    }
+    KDbTableSchema *table;
+    KDbConnection *conn;
+};
+
+KexiTablePartTempData::KexiTablePartTempData(KexiWindow* parent, KDbConnection *conn)
+        : KexiWindowData(parent)
+        , KDbTableSchemaChangeListener()
+        , tableSchemaChangedInPreviousView(true /*to force reloading on startup*/)
+        , d(new Private)
+{
+    d->conn = conn;
+    setName(KexiUtils::localizedStringToHtmlSubstring(
+        kxi18nc("@info", "Table <resource>%1</resource>").subs(parent->partItem()->name())));
+}
+
+KexiTablePartTempData::~KexiTablePartTempData()
+{
+    KDbTableSchemaChangeListener::unregisterForChanges(d->conn, this);
+    delete d;
+}
+
+KDbTableSchema* KexiTablePartTempData::table()
+{
+    return d->table;
+}
+
+KDbConnection* KexiTablePartTempData::connection()
+{
+    return d->conn;
+}
+
+void KexiTablePartTempData::closeDataInDataView()
+{
+    const KexiWindow* window = static_cast<KexiWindow*>(parent());
+    if (window->currentViewMode() != Kexi::DataViewMode) {
+        KexiTableDesigner_DataView *dataView
+            = qobject_cast<KexiTableDesigner_DataView*>(window->viewForMode(Kexi::DataViewMode));
+        if (dataView && dataView->tableView()->data()) {
+            dataView->setData(nullptr);
+        }
+    }
+}
+
+void KexiTablePartTempData::setTable(KDbTableSchema *table)
+{
+    if (d->table == table) {
+        return;
+    }
+    if (d->table) {
+        KDbTableSchemaChangeListener::unregisterForChanges(d->conn, d->table);
+    }
+    closeDataInDataView();
+    d->table = table;
+    if (d->table) {
+        KDbTableSchemaChangeListener::registerForChanges(d->conn, this, d->table);
+    }
+}
+
+tristate KexiTablePartTempData::closeListener()
+{
+    KexiWindow* window = static_cast<KexiWindow*>(parent());
+    qDebug() << window->partItem()->name();
+    closeDataInDataView();
+    if (closeWindowOnCloseListener) {
+        return KexiMainWindowIface::global()->closeWindow(window);
+    }
+    return true;
 }
 
 #include "kexitablepart.moc"
