@@ -177,11 +177,8 @@ void KexiDataAwareObjectInterface::setData(KDbTableViewData *data, bool owner)
         cancelRecordEditing();
         clearVariables();
     } else {
-        if (!m_insertRecord) {//first setData() call - add 'insert' item
-            m_insertRecord = m_data->createItem();
-        } else {//just reinit
-            m_insertRecord->resize(m_data->columnCount());
-        }
+        delete m_insertRecord;
+        m_insertRecord = m_data->createItem();
     }
 
     //update gui mode
@@ -241,7 +238,7 @@ void KexiDataAwareObjectInterface::setSortingEnabled(bool set)
     /*emit*/ reloadActions();
 }
 
-void KexiDataAwareObjectInterface::setSorting(int column, Qt::SortOrder order)
+void KexiDataAwareObjectInterface::setSorting(int column, KDbOrderByColumn::SortOrder order)
 {
     if (!m_data || !m_isSortingEnabled)
         return;
@@ -256,9 +253,9 @@ int KexiDataAwareObjectInterface::dataSortColumn() const
     return -1;
 }
 
-Qt::SortOrder KexiDataAwareObjectInterface::dataSortOrder() const
+KDbOrderByColumn::SortOrder KexiDataAwareObjectInterface::dataSortOrder() const
 {
-    return m_data ? m_data->sortOrder() : Qt::AscendingOrder;
+    return m_data ? m_data->sortOrder() : KDbOrderByColumn::SortOrder::Ascending;
 }
 
 bool KexiDataAwareObjectInterface::sort()
@@ -319,18 +316,19 @@ void KexiDataAwareObjectInterface::sortColumnInternal(int col, int order)
     //-select sorting
     bool asc;
     if (order == 0) {// invert
-        if (col == dataSortColumn() && dataSortOrder() == Qt::AscendingOrder)
+        if (col == dataSortColumn() && dataSortOrder() == KDbOrderByColumn::SortOrder::Ascending) {
             asc = false; // invert
-        else
+        } else {
             asc = true;
+        }
     }
     else {
         asc = (order == 1);
     }
 
-    const Qt::SortOrder prevSortOrder = currentLocalSortOrder();
+    const KDbOrderByColumn::SortOrder prevSortOrder = currentLocalSortOrder();
     const int prevSortColumn = currentLocalSortColumn();
-    setSorting(col, asc ? Qt::AscendingOrder : Qt::DescendingOrder);
+    setSorting(col, asc ? KDbOrderByColumn::SortOrder::Ascending : KDbOrderByColumn::SortOrder::Descending);
     //-perform sorting
     if (!sort()) {
         setLocalSortOrder(prevSortColumn, prevSortOrder); //this will also remove indicator
@@ -854,7 +852,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
             //! @todo allow displaying user-defined warning
             showEditorContextMessage(
                         m_editor,
-                        xi18nc("Question", "Error: %1?", m_editor->columnInfo()->field->typeName()),
+                        xi18nc("Question", "Error: %1?", m_editor->columnInfo()->field()->typeName()),
                         KMessageWidget::Error,
                         KMessageWidget::Up);
         }
@@ -982,7 +980,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
                 //move to faulty column (if m_editor is not cleared)
                 setCursorPosition(m_curRecord, m_data->result().column);
             }
-            if (!m_data->result().msg.isEmpty()) {
+            if (!m_data->result().message.isEmpty()) {
                 const int button = showErrorMessageForResult(m_data->result());
                 if (KMessageBox::No == button) {
                     //discard changes
@@ -1249,7 +1247,7 @@ int KexiDataAwareObjectInterface::columnType(int col)
 bool KexiDataAwareObjectInterface::columnEditable(int col)
 {
     KDbTableViewColumn* c = m_data ? column(col) : 0;
-    return c ? (! c->isReadOnly()) : false;
+    return c ? (!isReadOnly() && !c->isReadOnly()) : false;
 }
 
 QHeaderView* KexiDataAwareObjectInterface::horizontalHeader() const
@@ -1389,7 +1387,7 @@ KDbTableViewColumn* KexiDataAwareObjectInterface::column(int column)
 bool KexiDataAwareObjectInterface::hasDefaultValueAt(const KDbTableViewColumn& tvcol)
 {
     if (m_recordEditing >= 0 && m_data->recordEditBuffer() && m_data->recordEditBuffer()->isDBAware()) {
-        return m_data->recordEditBuffer()->hasDefaultValueAt(tvcol.columnInfo());
+        return m_data->recordEditBuffer()->hasDefaultValueAt(*tvcol.columnInfo());
     }
     return false;
 }
@@ -1629,8 +1627,8 @@ int KexiDataAwareObjectInterface::showErrorMessageForResult(const KDbResultInfo&
 {
     QWidget *thisWidget = dynamic_cast<QWidget*>(this);
     if (resultInfo.allowToDiscardChanges) {
-        return KMessageBox::questionYesNo(thisWidget, resultInfo.msg
-                                          + (resultInfo.desc.isEmpty() ? QString() : ("\n" + resultInfo.desc)),
+        return KMessageBox::questionYesNo(thisWidget, resultInfo.message
+                                          + (resultInfo.description.isEmpty() ? QString() : ("\n" + resultInfo.description)),
                                           QString(),
                                           KGuiItem(xi18nc("@action:button Correct Changes", "Correct"),
                                                    QString(),
@@ -1638,10 +1636,11 @@ int KexiDataAwareObjectInterface::showErrorMessageForResult(const KDbResultInfo&
                                           KGuiItem(xi18nc("@action:button", "Discard Changes")));
     }
 
-    if (resultInfo.desc.isEmpty())
-        KMessageBox::sorry(thisWidget, resultInfo.msg);
-    else
-        KMessageBox::detailedSorry(thisWidget, resultInfo.msg, resultInfo.desc);
+    if (resultInfo.description.isEmpty()) {
+        KMessageBox::sorry(thisWidget, resultInfo.message);
+    } else {
+        KMessageBox::detailedSorry(thisWidget, resultInfo.message, resultInfo.description);
+    }
 
     return KMessageBox::Ok;
 }
@@ -1952,8 +1951,8 @@ static QString lengthExceededMessage(KexiDataItemInterface *item)
         "Fix the text or it will be truncated upon saving changes.",
         "Limit of %2 characters for <resource>%3</resource> field has been exceeded by %1 characters.\n"
         "Fix the text or it will be truncated upon saving changes.",
-        item->value().toString().length() - item->columnInfo()->field->maxLength(),
-        item->columnInfo()->field->maxLength(),
+        item->value().toString().length() - item->columnInfo()->field()->maxLength(),
+        item->columnInfo()->field()->maxLength(),
         item->columnInfo()->captionOrAliasOrName());
 }
 
