@@ -42,7 +42,7 @@
 #define NO_LOAD_DB_LIST
 
 // @internal
-class KexiDBConnectionWidget::Private
+class Q_DECL_HIDDEN KexiDBConnectionWidget::Private
 {
 public:
     Private()
@@ -56,7 +56,7 @@ public:
     QAction *savePasswordHelpAction;
 };
 
-class KexiDBConnectionDialog::Private
+class Q_DECL_HIDDEN KexiDBConnectionDialog::Private
 {
 public:
     Private() { }
@@ -73,7 +73,7 @@ KexiDBConnectionWidget::KexiDBConnectionWidget(QWidget* parent)
 {
     setupUi(this);
     setObjectName("KexiConnectionSelectorWidget");
-    iconLabel->setPixmap(DesktopIcon(Kexi::serverIconName()));
+    iconLabel->setPixmap(koDesktopIconCStr(Kexi::serverIconName()));
 
     QVBoxLayout *driversComboLyr = new QVBoxLayout(frmEngine);
     driversComboLyr->setMargin(0);
@@ -366,7 +366,7 @@ void KexiDBConnectionTabWidget::slotTestConnection()
         }
     }
     KexiGUIMessageHandler msgHandler;
-    KDb::connectionTestDialog(this, connectionData, &msgHandler);
+    KDb::showConnectionTestDialog(this, connectionData, &msgHandler);
 }
 
 void KexiDBConnectionTabWidget::slotSocketComboboxToggled(bool on)
