@@ -53,7 +53,7 @@ struct PixmapAndPos {
 };
 
 //! @internal
-class KexiBlobTableEdit::Private
+class Q_DECL_HIDDEN KexiBlobTableEdit::Private
 {
 public:
     Private()
@@ -73,7 +73,7 @@ public:
 
 //======================================================
 
-KexiBlobTableEdit::KexiBlobTableEdit(KDbTableViewColumn &column, QWidget *parent)
+KexiBlobTableEdit::KexiBlobTableEdit(KDbTableViewColumn *column, QWidget *parent)
         : KexiTableEdit(column, parent)
         , d(new Private())
 {
@@ -84,8 +84,8 @@ KexiBlobTableEdit::KexiBlobTableEdit(KDbTableViewColumn &column, QWidget *parent
 
     d->menu = new KexiImageContextMenu(this);
     d->menu->installEventFilter(this);
-    if (column.columnInfo())
-        KexiImageContextMenu::updateTitle(d->menu, column.columnInfo()->captionOrAliasOrName(),
+    if (column->columnInfo())
+        KexiImageContextMenu::updateTitle(d->menu, column->columnInfo()->captionOrAliasOrName(),
 //! @todo pixmaplabel icon is hardcoded...
                                           KexiIconName("imagebox"));
     d->button->setMenu(d->menu);
@@ -488,7 +488,7 @@ KEXI_CELLEDITOR_FACTORY_ITEM_IMPL(KexiBlobEditorFactoryItem, KexiBlobTableEdit)
 // KexiKIconTableEdit class is temporarily here:
 
 //! @internal
-class KexiKIconTableEdit::Private
+class Q_DECL_HIDDEN KexiKIconTableEdit::Private
 {
 public:
     Private()
@@ -500,7 +500,7 @@ public:
     QCache<QString, QPixmap> pixmapCache;
 };
 
-KexiKIconTableEdit::KexiKIconTableEdit(KDbTableViewColumn &column, QWidget *parent)
+KexiKIconTableEdit::KexiKIconTableEdit(KDbTableViewColumn *column, QWidget *parent)
         : KexiTableEdit(column, parent)
         , d(new Private())
 {
