@@ -25,7 +25,7 @@
 #include <QLocale>
 
 //! @internal
-class KexiTextFormatter::Private
+class Q_DECL_HIDDEN KexiTextFormatter::Private
 {
 public:
     Private() : field(nullptr), dateFormatter(nullptr), timeFormatter(nullptr) {
@@ -140,10 +140,11 @@ QString KexiTextFormatter::toString(const QVariant& value, const QString& add,
             return add.isEmpty() ? QString::fromLatin1("0") : add; //eat 0
         }
         return KDb::numberToLocaleString(
-            value.toDouble(), // use Double for Float too for better accuracy
-            d->overrideDecimalPlaces.enabled ? d->overrideDecimalPlaces.value
-                                             : d->field->visibleDecimalPlaces(),
-            &d->locale) + add;
+                   value.toDouble(), // use Double for Float too for better accuracy
+                   d->overrideDecimalPlaces.enabled ? d->overrideDecimalPlaces.value
+                                                    : d->field->visibleDecimalPlaces(),
+                   d->locale)
+            + add;
     }
 
     switch (d->field->type()) {
@@ -207,10 +208,12 @@ QVariant KexiTextFormatter::fromString(const QString& text, bool *ok) const
             result = text == QString::fromLatin1("1");
             break;
         case KDbField::Date:
-            result = d->dateFormatter->stringToVariant(text, ok);
+            result = d->dateFormatter->stringToVariant(text);
+            *ok = !result.isNull();
             break;
         case KDbField::Time:
-            result = d->timeFormatter->stringToVariant(text, ok);
+            result = d->timeFormatter->stringToVariant(text);
+            *ok = !result.isNull();
             break;
         case KDbField::DateTime: {
             const QDateTime dt(KexiDateTimeFormatter::fromString(
